# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'AuthenticationRuleChildren',
    'AuthenticationRuleChildrenChildren',
    'AuthorizationExceptionRuleChildren',
    'AuthorizationExceptionRuleChildrenChildren',
    'AuthorizationGlobalExceptionRuleChildren',
    'AuthorizationGlobalExceptionRuleChildrenChildren',
    'AuthorizationProfileAdvancedAttribute',
    'AuthorizationRuleChildren',
    'AuthorizationRuleChildrenChildren',
    'ConditionChildren',
    'ConditionChildrenChildren',
    'PolicySetChildren',
    'PolicySetChildrenChildren',
    'GetAuthenticationRuleChildrenResult',
    'GetAuthenticationRuleChildrenChildrenResult',
    'GetAuthorizationExceptionRuleChildrenResult',
    'GetAuthorizationExceptionRuleChildrenChildrenResult',
    'GetAuthorizationGlobalExceptionRuleChildrenResult',
    'GetAuthorizationGlobalExceptionRuleChildrenChildrenResult',
    'GetAuthorizationProfileAdvancedAttributeResult',
    'GetAuthorizationRuleChildrenResult',
    'GetAuthorizationRuleChildrenChildrenResult',
    'GetConditionChildrenResult',
    'GetConditionChildrenChildrenResult',
    'GetPolicySetChildrenResult',
    'GetPolicySetChildrenChildrenResult',
]

@pulumi.output_type
class AuthenticationRuleChildren(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "conditionType":
            suggest = "condition_type"
        elif key == "attributeName":
            suggest = "attribute_name"
        elif key == "attributeValue":
            suggest = "attribute_value"
        elif key == "dictionaryName":
            suggest = "dictionary_name"
        elif key == "dictionaryValue":
            suggest = "dictionary_value"
        elif key == "isNegate":
            suggest = "is_negate"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in AuthenticationRuleChildren. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        AuthenticationRuleChildren.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        AuthenticationRuleChildren.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 condition_type: builtins.str,
                 attribute_name: Optional[builtins.str] = None,
                 attribute_value: Optional[builtins.str] = None,
                 childrens: Optional[Sequence['outputs.AuthenticationRuleChildrenChildren']] = None,
                 dictionary_name: Optional[builtins.str] = None,
                 dictionary_value: Optional[builtins.str] = None,
                 id: Optional[builtins.str] = None,
                 is_negate: Optional[builtins.bool] = None,
                 operator: Optional[builtins.str] = None):
        """
        :param builtins.str condition_type: Indicates whether the record is the condition itself or a logical aggregation. Logical aggreation indicates that additional conditions are present under the children attribute.
                 - Choices: `ConditionAndBlock`, `ConditionAttributes`, `ConditionOrBlock`, `ConditionReference`
        :param builtins.str attribute_name: Dictionary attribute name
        :param builtins.str attribute_value: Attribute value for condition. Value type is specified in dictionary object.
        :param Sequence['AuthenticationRuleChildrenChildrenArgs'] childrens: List of child conditions. `condition_type` must be one of `ConditionAndBlock` or `ConditionOrBlock`.
        :param builtins.str dictionary_name: Dictionary name
        :param builtins.str dictionary_value: Dictionary value
        :param builtins.str id: UUID for condition
        :param builtins.bool is_negate: Indicates whereas this condition is in negate mode
        :param builtins.str operator: Equality operator
                 - Choices: `contains`, `endsWith`, `equals`, `greaterOrEquals`, `greaterThan`, `in`, `ipEquals`, `ipGreaterThan`, `ipLessThan`, `ipNotEquals`, `lessOrEquals`, `lessThan`, `matches`, `notContains`, `notEndsWith`, `notEquals`, `notIn`, `notStartsWith`, `startsWith`
        """
        pulumi.set(__self__, "condition_type", condition_type)
        if attribute_name is not None:
            pulumi.set(__self__, "attribute_name", attribute_name)
        if attribute_value is not None:
            pulumi.set(__self__, "attribute_value", attribute_value)
        if childrens is not None:
            pulumi.set(__self__, "childrens", childrens)
        if dictionary_name is not None:
            pulumi.set(__self__, "dictionary_name", dictionary_name)
        if dictionary_value is not None:
            pulumi.set(__self__, "dictionary_value", dictionary_value)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if is_negate is not None:
            pulumi.set(__self__, "is_negate", is_negate)
        if operator is not None:
            pulumi.set(__self__, "operator", operator)

    @property
    @pulumi.getter(name="conditionType")
    def condition_type(self) -> builtins.str:
        """
        Indicates whether the record is the condition itself or a logical aggregation. Logical aggreation indicates that additional conditions are present under the children attribute.
          - Choices: `ConditionAndBlock`, `ConditionAttributes`, `ConditionOrBlock`, `ConditionReference`
        """
        return pulumi.get(self, "condition_type")

    @property
    @pulumi.getter(name="attributeName")
    def attribute_name(self) -> Optional[builtins.str]:
        """
        Dictionary attribute name
        """
        return pulumi.get(self, "attribute_name")

    @property
    @pulumi.getter(name="attributeValue")
    def attribute_value(self) -> Optional[builtins.str]:
        """
        Attribute value for condition. Value type is specified in dictionary object.
        """
        return pulumi.get(self, "attribute_value")

    @property
    @pulumi.getter
    def childrens(self) -> Optional[Sequence['outputs.AuthenticationRuleChildrenChildren']]:
        """
        List of child conditions. `condition_type` must be one of `ConditionAndBlock` or `ConditionOrBlock`.
        """
        return pulumi.get(self, "childrens")

    @property
    @pulumi.getter(name="dictionaryName")
    def dictionary_name(self) -> Optional[builtins.str]:
        """
        Dictionary name
        """
        return pulumi.get(self, "dictionary_name")

    @property
    @pulumi.getter(name="dictionaryValue")
    def dictionary_value(self) -> Optional[builtins.str]:
        """
        Dictionary value
        """
        return pulumi.get(self, "dictionary_value")

    @property
    @pulumi.getter
    def id(self) -> Optional[builtins.str]:
        """
        UUID for condition
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isNegate")
    def is_negate(self) -> Optional[builtins.bool]:
        """
        Indicates whereas this condition is in negate mode
        """
        return pulumi.get(self, "is_negate")

    @property
    @pulumi.getter
    def operator(self) -> Optional[builtins.str]:
        """
        Equality operator
          - Choices: `contains`, `endsWith`, `equals`, `greaterOrEquals`, `greaterThan`, `in`, `ipEquals`, `ipGreaterThan`, `ipLessThan`, `ipNotEquals`, `lessOrEquals`, `lessThan`, `matches`, `notContains`, `notEndsWith`, `notEquals`, `notIn`, `notStartsWith`, `startsWith`
        """
        return pulumi.get(self, "operator")


@pulumi.output_type
class AuthenticationRuleChildrenChildren(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "conditionType":
            suggest = "condition_type"
        elif key == "attributeName":
            suggest = "attribute_name"
        elif key == "attributeValue":
            suggest = "attribute_value"
        elif key == "dictionaryName":
            suggest = "dictionary_name"
        elif key == "dictionaryValue":
            suggest = "dictionary_value"
        elif key == "isNegate":
            suggest = "is_negate"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in AuthenticationRuleChildrenChildren. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        AuthenticationRuleChildrenChildren.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        AuthenticationRuleChildrenChildren.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 condition_type: builtins.str,
                 attribute_name: Optional[builtins.str] = None,
                 attribute_value: Optional[builtins.str] = None,
                 dictionary_name: Optional[builtins.str] = None,
                 dictionary_value: Optional[builtins.str] = None,
                 id: Optional[builtins.str] = None,
                 is_negate: Optional[builtins.bool] = None,
                 operator: Optional[builtins.str] = None):
        """
        :param builtins.str condition_type: Condition type.
                 - Choices: `ConditionAttributes`, `ConditionReference`
        :param builtins.str attribute_name: Dictionary attribute name
        :param builtins.str attribute_value: Attribute value for condition. Value type is specified in dictionary object.
        :param builtins.str dictionary_name: Dictionary name
        :param builtins.str dictionary_value: Dictionary value
        :param builtins.str id: UUID for condition
        :param builtins.bool is_negate: Indicates whereas this condition is in negate mode
        :param builtins.str operator: Equality operator
                 - Choices: `contains`, `endsWith`, `equals`, `greaterOrEquals`, `greaterThan`, `in`, `ipEquals`, `ipGreaterThan`, `ipLessThan`, `ipNotEquals`, `lessOrEquals`, `lessThan`, `matches`, `notContains`, `notEndsWith`, `notEquals`, `notIn`, `notStartsWith`, `startsWith`
        """
        pulumi.set(__self__, "condition_type", condition_type)
        if attribute_name is not None:
            pulumi.set(__self__, "attribute_name", attribute_name)
        if attribute_value is not None:
            pulumi.set(__self__, "attribute_value", attribute_value)
        if dictionary_name is not None:
            pulumi.set(__self__, "dictionary_name", dictionary_name)
        if dictionary_value is not None:
            pulumi.set(__self__, "dictionary_value", dictionary_value)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if is_negate is not None:
            pulumi.set(__self__, "is_negate", is_negate)
        if operator is not None:
            pulumi.set(__self__, "operator", operator)

    @property
    @pulumi.getter(name="conditionType")
    def condition_type(self) -> builtins.str:
        """
        Condition type.
          - Choices: `ConditionAttributes`, `ConditionReference`
        """
        return pulumi.get(self, "condition_type")

    @property
    @pulumi.getter(name="attributeName")
    def attribute_name(self) -> Optional[builtins.str]:
        """
        Dictionary attribute name
        """
        return pulumi.get(self, "attribute_name")

    @property
    @pulumi.getter(name="attributeValue")
    def attribute_value(self) -> Optional[builtins.str]:
        """
        Attribute value for condition. Value type is specified in dictionary object.
        """
        return pulumi.get(self, "attribute_value")

    @property
    @pulumi.getter(name="dictionaryName")
    def dictionary_name(self) -> Optional[builtins.str]:
        """
        Dictionary name
        """
        return pulumi.get(self, "dictionary_name")

    @property
    @pulumi.getter(name="dictionaryValue")
    def dictionary_value(self) -> Optional[builtins.str]:
        """
        Dictionary value
        """
        return pulumi.get(self, "dictionary_value")

    @property
    @pulumi.getter
    def id(self) -> Optional[builtins.str]:
        """
        UUID for condition
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isNegate")
    def is_negate(self) -> Optional[builtins.bool]:
        """
        Indicates whereas this condition is in negate mode
        """
        return pulumi.get(self, "is_negate")

    @property
    @pulumi.getter
    def operator(self) -> Optional[builtins.str]:
        """
        Equality operator
          - Choices: `contains`, `endsWith`, `equals`, `greaterOrEquals`, `greaterThan`, `in`, `ipEquals`, `ipGreaterThan`, `ipLessThan`, `ipNotEquals`, `lessOrEquals`, `lessThan`, `matches`, `notContains`, `notEndsWith`, `notEquals`, `notIn`, `notStartsWith`, `startsWith`
        """
        return pulumi.get(self, "operator")


@pulumi.output_type
class AuthorizationExceptionRuleChildren(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "conditionType":
            suggest = "condition_type"
        elif key == "attributeName":
            suggest = "attribute_name"
        elif key == "attributeValue":
            suggest = "attribute_value"
        elif key == "dictionaryName":
            suggest = "dictionary_name"
        elif key == "dictionaryValue":
            suggest = "dictionary_value"
        elif key == "isNegate":
            suggest = "is_negate"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in AuthorizationExceptionRuleChildren. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        AuthorizationExceptionRuleChildren.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        AuthorizationExceptionRuleChildren.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 condition_type: builtins.str,
                 attribute_name: Optional[builtins.str] = None,
                 attribute_value: Optional[builtins.str] = None,
                 childrens: Optional[Sequence['outputs.AuthorizationExceptionRuleChildrenChildren']] = None,
                 dictionary_name: Optional[builtins.str] = None,
                 dictionary_value: Optional[builtins.str] = None,
                 id: Optional[builtins.str] = None,
                 is_negate: Optional[builtins.bool] = None,
                 operator: Optional[builtins.str] = None):
        """
        :param builtins.str condition_type: Indicates whether the record is the condition itself or a logical aggregation. Logical aggreation indicates that additional conditions are present under the children attribute.
                 - Choices: `ConditionAndBlock`, `ConditionAttributes`, `ConditionOrBlock`, `ConditionReference`
        :param builtins.str attribute_name: Dictionary attribute name
        :param builtins.str attribute_value: Attribute value for condition. Value type is specified in dictionary object.
        :param Sequence['AuthorizationExceptionRuleChildrenChildrenArgs'] childrens: List of child conditions. `condition_type` must be one of `ConditionAndBlock` or `ConditionOrBlock`.
        :param builtins.str dictionary_name: Dictionary name
        :param builtins.str dictionary_value: Dictionary value
        :param builtins.str id: UUID for condition
        :param builtins.bool is_negate: Indicates whereas this condition is in negate mode
        :param builtins.str operator: Equality operator
                 - Choices: `contains`, `endsWith`, `equals`, `greaterOrEquals`, `greaterThan`, `in`, `ipEquals`, `ipGreaterThan`, `ipLessThan`, `ipNotEquals`, `lessOrEquals`, `lessThan`, `matches`, `notContains`, `notEndsWith`, `notEquals`, `notIn`, `notStartsWith`, `startsWith`
        """
        pulumi.set(__self__, "condition_type", condition_type)
        if attribute_name is not None:
            pulumi.set(__self__, "attribute_name", attribute_name)
        if attribute_value is not None:
            pulumi.set(__self__, "attribute_value", attribute_value)
        if childrens is not None:
            pulumi.set(__self__, "childrens", childrens)
        if dictionary_name is not None:
            pulumi.set(__self__, "dictionary_name", dictionary_name)
        if dictionary_value is not None:
            pulumi.set(__self__, "dictionary_value", dictionary_value)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if is_negate is not None:
            pulumi.set(__self__, "is_negate", is_negate)
        if operator is not None:
            pulumi.set(__self__, "operator", operator)

    @property
    @pulumi.getter(name="conditionType")
    def condition_type(self) -> builtins.str:
        """
        Indicates whether the record is the condition itself or a logical aggregation. Logical aggreation indicates that additional conditions are present under the children attribute.
          - Choices: `ConditionAndBlock`, `ConditionAttributes`, `ConditionOrBlock`, `ConditionReference`
        """
        return pulumi.get(self, "condition_type")

    @property
    @pulumi.getter(name="attributeName")
    def attribute_name(self) -> Optional[builtins.str]:
        """
        Dictionary attribute name
        """
        return pulumi.get(self, "attribute_name")

    @property
    @pulumi.getter(name="attributeValue")
    def attribute_value(self) -> Optional[builtins.str]:
        """
        Attribute value for condition. Value type is specified in dictionary object.
        """
        return pulumi.get(self, "attribute_value")

    @property
    @pulumi.getter
    def childrens(self) -> Optional[Sequence['outputs.AuthorizationExceptionRuleChildrenChildren']]:
        """
        List of child conditions. `condition_type` must be one of `ConditionAndBlock` or `ConditionOrBlock`.
        """
        return pulumi.get(self, "childrens")

    @property
    @pulumi.getter(name="dictionaryName")
    def dictionary_name(self) -> Optional[builtins.str]:
        """
        Dictionary name
        """
        return pulumi.get(self, "dictionary_name")

    @property
    @pulumi.getter(name="dictionaryValue")
    def dictionary_value(self) -> Optional[builtins.str]:
        """
        Dictionary value
        """
        return pulumi.get(self, "dictionary_value")

    @property
    @pulumi.getter
    def id(self) -> Optional[builtins.str]:
        """
        UUID for condition
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isNegate")
    def is_negate(self) -> Optional[builtins.bool]:
        """
        Indicates whereas this condition is in negate mode
        """
        return pulumi.get(self, "is_negate")

    @property
    @pulumi.getter
    def operator(self) -> Optional[builtins.str]:
        """
        Equality operator
          - Choices: `contains`, `endsWith`, `equals`, `greaterOrEquals`, `greaterThan`, `in`, `ipEquals`, `ipGreaterThan`, `ipLessThan`, `ipNotEquals`, `lessOrEquals`, `lessThan`, `matches`, `notContains`, `notEndsWith`, `notEquals`, `notIn`, `notStartsWith`, `startsWith`
        """
        return pulumi.get(self, "operator")


@pulumi.output_type
class AuthorizationExceptionRuleChildrenChildren(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "conditionType":
            suggest = "condition_type"
        elif key == "attributeName":
            suggest = "attribute_name"
        elif key == "attributeValue":
            suggest = "attribute_value"
        elif key == "dictionaryName":
            suggest = "dictionary_name"
        elif key == "dictionaryValue":
            suggest = "dictionary_value"
        elif key == "isNegate":
            suggest = "is_negate"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in AuthorizationExceptionRuleChildrenChildren. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        AuthorizationExceptionRuleChildrenChildren.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        AuthorizationExceptionRuleChildrenChildren.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 condition_type: builtins.str,
                 attribute_name: Optional[builtins.str] = None,
                 attribute_value: Optional[builtins.str] = None,
                 dictionary_name: Optional[builtins.str] = None,
                 dictionary_value: Optional[builtins.str] = None,
                 id: Optional[builtins.str] = None,
                 is_negate: Optional[builtins.bool] = None,
                 operator: Optional[builtins.str] = None):
        """
        :param builtins.str condition_type: Condition type.
                 - Choices: `ConditionAttributes`, `ConditionReference`
        :param builtins.str attribute_name: Dictionary attribute name
        :param builtins.str attribute_value: Attribute value for condition. Value type is specified in dictionary object.
        :param builtins.str dictionary_name: Dictionary name
        :param builtins.str dictionary_value: Dictionary value
        :param builtins.str id: UUID for condition
        :param builtins.bool is_negate: Indicates whereas this condition is in negate mode
        :param builtins.str operator: Equality operator
                 - Choices: `contains`, `endsWith`, `equals`, `greaterOrEquals`, `greaterThan`, `in`, `ipEquals`, `ipGreaterThan`, `ipLessThan`, `ipNotEquals`, `lessOrEquals`, `lessThan`, `matches`, `notContains`, `notEndsWith`, `notEquals`, `notIn`, `notStartsWith`, `startsWith`
        """
        pulumi.set(__self__, "condition_type", condition_type)
        if attribute_name is not None:
            pulumi.set(__self__, "attribute_name", attribute_name)
        if attribute_value is not None:
            pulumi.set(__self__, "attribute_value", attribute_value)
        if dictionary_name is not None:
            pulumi.set(__self__, "dictionary_name", dictionary_name)
        if dictionary_value is not None:
            pulumi.set(__self__, "dictionary_value", dictionary_value)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if is_negate is not None:
            pulumi.set(__self__, "is_negate", is_negate)
        if operator is not None:
            pulumi.set(__self__, "operator", operator)

    @property
    @pulumi.getter(name="conditionType")
    def condition_type(self) -> builtins.str:
        """
        Condition type.
          - Choices: `ConditionAttributes`, `ConditionReference`
        """
        return pulumi.get(self, "condition_type")

    @property
    @pulumi.getter(name="attributeName")
    def attribute_name(self) -> Optional[builtins.str]:
        """
        Dictionary attribute name
        """
        return pulumi.get(self, "attribute_name")

    @property
    @pulumi.getter(name="attributeValue")
    def attribute_value(self) -> Optional[builtins.str]:
        """
        Attribute value for condition. Value type is specified in dictionary object.
        """
        return pulumi.get(self, "attribute_value")

    @property
    @pulumi.getter(name="dictionaryName")
    def dictionary_name(self) -> Optional[builtins.str]:
        """
        Dictionary name
        """
        return pulumi.get(self, "dictionary_name")

    @property
    @pulumi.getter(name="dictionaryValue")
    def dictionary_value(self) -> Optional[builtins.str]:
        """
        Dictionary value
        """
        return pulumi.get(self, "dictionary_value")

    @property
    @pulumi.getter
    def id(self) -> Optional[builtins.str]:
        """
        UUID for condition
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isNegate")
    def is_negate(self) -> Optional[builtins.bool]:
        """
        Indicates whereas this condition is in negate mode
        """
        return pulumi.get(self, "is_negate")

    @property
    @pulumi.getter
    def operator(self) -> Optional[builtins.str]:
        """
        Equality operator
          - Choices: `contains`, `endsWith`, `equals`, `greaterOrEquals`, `greaterThan`, `in`, `ipEquals`, `ipGreaterThan`, `ipLessThan`, `ipNotEquals`, `lessOrEquals`, `lessThan`, `matches`, `notContains`, `notEndsWith`, `notEquals`, `notIn`, `notStartsWith`, `startsWith`
        """
        return pulumi.get(self, "operator")


@pulumi.output_type
class AuthorizationGlobalExceptionRuleChildren(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "conditionType":
            suggest = "condition_type"
        elif key == "attributeName":
            suggest = "attribute_name"
        elif key == "attributeValue":
            suggest = "attribute_value"
        elif key == "dictionaryName":
            suggest = "dictionary_name"
        elif key == "dictionaryValue":
            suggest = "dictionary_value"
        elif key == "isNegate":
            suggest = "is_negate"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in AuthorizationGlobalExceptionRuleChildren. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        AuthorizationGlobalExceptionRuleChildren.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        AuthorizationGlobalExceptionRuleChildren.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 condition_type: builtins.str,
                 attribute_name: Optional[builtins.str] = None,
                 attribute_value: Optional[builtins.str] = None,
                 childrens: Optional[Sequence['outputs.AuthorizationGlobalExceptionRuleChildrenChildren']] = None,
                 dictionary_name: Optional[builtins.str] = None,
                 dictionary_value: Optional[builtins.str] = None,
                 id: Optional[builtins.str] = None,
                 is_negate: Optional[builtins.bool] = None,
                 operator: Optional[builtins.str] = None):
        """
        :param builtins.str condition_type: Indicates whether the record is the condition itself or a logical aggregation. Logical aggreation indicates that additional conditions are present under the children attribute.
                 - Choices: `ConditionAndBlock`, `ConditionAttributes`, `ConditionOrBlock`, `ConditionReference`
        :param builtins.str attribute_name: Dictionary attribute name
        :param builtins.str attribute_value: Attribute value for condition. Value type is specified in dictionary object.
        :param Sequence['AuthorizationGlobalExceptionRuleChildrenChildrenArgs'] childrens: List of child conditions. `condition_type` must be one of `ConditionAndBlock` or `ConditionOrBlock`.
        :param builtins.str dictionary_name: Dictionary name
        :param builtins.str dictionary_value: Dictionary value
        :param builtins.str id: UUID for condition
        :param builtins.bool is_negate: Indicates whereas this condition is in negate mode
        :param builtins.str operator: Equality operator
                 - Choices: `contains`, `endsWith`, `equals`, `greaterOrEquals`, `greaterThan`, `in`, `ipEquals`, `ipGreaterThan`, `ipLessThan`, `ipNotEquals`, `lessOrEquals`, `lessThan`, `matches`, `notContains`, `notEndsWith`, `notEquals`, `notIn`, `notStartsWith`, `startsWith`
        """
        pulumi.set(__self__, "condition_type", condition_type)
        if attribute_name is not None:
            pulumi.set(__self__, "attribute_name", attribute_name)
        if attribute_value is not None:
            pulumi.set(__self__, "attribute_value", attribute_value)
        if childrens is not None:
            pulumi.set(__self__, "childrens", childrens)
        if dictionary_name is not None:
            pulumi.set(__self__, "dictionary_name", dictionary_name)
        if dictionary_value is not None:
            pulumi.set(__self__, "dictionary_value", dictionary_value)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if is_negate is not None:
            pulumi.set(__self__, "is_negate", is_negate)
        if operator is not None:
            pulumi.set(__self__, "operator", operator)

    @property
    @pulumi.getter(name="conditionType")
    def condition_type(self) -> builtins.str:
        """
        Indicates whether the record is the condition itself or a logical aggregation. Logical aggreation indicates that additional conditions are present under the children attribute.
          - Choices: `ConditionAndBlock`, `ConditionAttributes`, `ConditionOrBlock`, `ConditionReference`
        """
        return pulumi.get(self, "condition_type")

    @property
    @pulumi.getter(name="attributeName")
    def attribute_name(self) -> Optional[builtins.str]:
        """
        Dictionary attribute name
        """
        return pulumi.get(self, "attribute_name")

    @property
    @pulumi.getter(name="attributeValue")
    def attribute_value(self) -> Optional[builtins.str]:
        """
        Attribute value for condition. Value type is specified in dictionary object.
        """
        return pulumi.get(self, "attribute_value")

    @property
    @pulumi.getter
    def childrens(self) -> Optional[Sequence['outputs.AuthorizationGlobalExceptionRuleChildrenChildren']]:
        """
        List of child conditions. `condition_type` must be one of `ConditionAndBlock` or `ConditionOrBlock`.
        """
        return pulumi.get(self, "childrens")

    @property
    @pulumi.getter(name="dictionaryName")
    def dictionary_name(self) -> Optional[builtins.str]:
        """
        Dictionary name
        """
        return pulumi.get(self, "dictionary_name")

    @property
    @pulumi.getter(name="dictionaryValue")
    def dictionary_value(self) -> Optional[builtins.str]:
        """
        Dictionary value
        """
        return pulumi.get(self, "dictionary_value")

    @property
    @pulumi.getter
    def id(self) -> Optional[builtins.str]:
        """
        UUID for condition
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isNegate")
    def is_negate(self) -> Optional[builtins.bool]:
        """
        Indicates whereas this condition is in negate mode
        """
        return pulumi.get(self, "is_negate")

    @property
    @pulumi.getter
    def operator(self) -> Optional[builtins.str]:
        """
        Equality operator
          - Choices: `contains`, `endsWith`, `equals`, `greaterOrEquals`, `greaterThan`, `in`, `ipEquals`, `ipGreaterThan`, `ipLessThan`, `ipNotEquals`, `lessOrEquals`, `lessThan`, `matches`, `notContains`, `notEndsWith`, `notEquals`, `notIn`, `notStartsWith`, `startsWith`
        """
        return pulumi.get(self, "operator")


@pulumi.output_type
class AuthorizationGlobalExceptionRuleChildrenChildren(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "conditionType":
            suggest = "condition_type"
        elif key == "attributeName":
            suggest = "attribute_name"
        elif key == "attributeValue":
            suggest = "attribute_value"
        elif key == "dictionaryName":
            suggest = "dictionary_name"
        elif key == "dictionaryValue":
            suggest = "dictionary_value"
        elif key == "isNegate":
            suggest = "is_negate"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in AuthorizationGlobalExceptionRuleChildrenChildren. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        AuthorizationGlobalExceptionRuleChildrenChildren.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        AuthorizationGlobalExceptionRuleChildrenChildren.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 condition_type: builtins.str,
                 attribute_name: Optional[builtins.str] = None,
                 attribute_value: Optional[builtins.str] = None,
                 dictionary_name: Optional[builtins.str] = None,
                 dictionary_value: Optional[builtins.str] = None,
                 id: Optional[builtins.str] = None,
                 is_negate: Optional[builtins.bool] = None,
                 operator: Optional[builtins.str] = None):
        """
        :param builtins.str condition_type: Condition type.
                 - Choices: `ConditionAttributes`, `ConditionReference`
        :param builtins.str attribute_name: Dictionary attribute name
        :param builtins.str attribute_value: Attribute value for condition. Value type is specified in dictionary object.
        :param builtins.str dictionary_name: Dictionary name
        :param builtins.str dictionary_value: Dictionary value
        :param builtins.str id: UUID for condition
        :param builtins.bool is_negate: Indicates whereas this condition is in negate mode
        :param builtins.str operator: Equality operator
                 - Choices: `contains`, `endsWith`, `equals`, `greaterOrEquals`, `greaterThan`, `in`, `ipEquals`, `ipGreaterThan`, `ipLessThan`, `ipNotEquals`, `lessOrEquals`, `lessThan`, `matches`, `notContains`, `notEndsWith`, `notEquals`, `notIn`, `notStartsWith`, `startsWith`
        """
        pulumi.set(__self__, "condition_type", condition_type)
        if attribute_name is not None:
            pulumi.set(__self__, "attribute_name", attribute_name)
        if attribute_value is not None:
            pulumi.set(__self__, "attribute_value", attribute_value)
        if dictionary_name is not None:
            pulumi.set(__self__, "dictionary_name", dictionary_name)
        if dictionary_value is not None:
            pulumi.set(__self__, "dictionary_value", dictionary_value)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if is_negate is not None:
            pulumi.set(__self__, "is_negate", is_negate)
        if operator is not None:
            pulumi.set(__self__, "operator", operator)

    @property
    @pulumi.getter(name="conditionType")
    def condition_type(self) -> builtins.str:
        """
        Condition type.
          - Choices: `ConditionAttributes`, `ConditionReference`
        """
        return pulumi.get(self, "condition_type")

    @property
    @pulumi.getter(name="attributeName")
    def attribute_name(self) -> Optional[builtins.str]:
        """
        Dictionary attribute name
        """
        return pulumi.get(self, "attribute_name")

    @property
    @pulumi.getter(name="attributeValue")
    def attribute_value(self) -> Optional[builtins.str]:
        """
        Attribute value for condition. Value type is specified in dictionary object.
        """
        return pulumi.get(self, "attribute_value")

    @property
    @pulumi.getter(name="dictionaryName")
    def dictionary_name(self) -> Optional[builtins.str]:
        """
        Dictionary name
        """
        return pulumi.get(self, "dictionary_name")

    @property
    @pulumi.getter(name="dictionaryValue")
    def dictionary_value(self) -> Optional[builtins.str]:
        """
        Dictionary value
        """
        return pulumi.get(self, "dictionary_value")

    @property
    @pulumi.getter
    def id(self) -> Optional[builtins.str]:
        """
        UUID for condition
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isNegate")
    def is_negate(self) -> Optional[builtins.bool]:
        """
        Indicates whereas this condition is in negate mode
        """
        return pulumi.get(self, "is_negate")

    @property
    @pulumi.getter
    def operator(self) -> Optional[builtins.str]:
        """
        Equality operator
          - Choices: `contains`, `endsWith`, `equals`, `greaterOrEquals`, `greaterThan`, `in`, `ipEquals`, `ipGreaterThan`, `ipLessThan`, `ipNotEquals`, `lessOrEquals`, `lessThan`, `matches`, `notContains`, `notEndsWith`, `notEquals`, `notIn`, `notStartsWith`, `startsWith`
        """
        return pulumi.get(self, "operator")


@pulumi.output_type
class AuthorizationProfileAdvancedAttribute(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "attributeLeftDictionaryName":
            suggest = "attribute_left_dictionary_name"
        elif key == "attributeLeftName":
            suggest = "attribute_left_name"
        elif key == "attributeRightDictionaryName":
            suggest = "attribute_right_dictionary_name"
        elif key == "attributeRightName":
            suggest = "attribute_right_name"
        elif key == "attributeRightValue":
            suggest = "attribute_right_value"
        elif key == "attributeRightValueType":
            suggest = "attribute_right_value_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in AuthorizationProfileAdvancedAttribute. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        AuthorizationProfileAdvancedAttribute.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        AuthorizationProfileAdvancedAttribute.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 attribute_left_dictionary_name: Optional[builtins.str] = None,
                 attribute_left_name: Optional[builtins.str] = None,
                 attribute_right_dictionary_name: Optional[builtins.str] = None,
                 attribute_right_name: Optional[builtins.str] = None,
                 attribute_right_value: Optional[builtins.str] = None,
                 attribute_right_value_type: Optional[builtins.str] = None):
        """
        :param builtins.str attribute_left_dictionary_name: Dictionary name
        :param builtins.str attribute_left_name: Attribute name
        :param builtins.str attribute_right_dictionary_name: Dictionary name, only required when `attribute_right_value_type` is `AdvancedDictionaryAttribute`
        :param builtins.str attribute_right_name: Attribute name, only required when `attribute_right_value_type` is `AdvancedDictionaryAttribute`
        :param builtins.str attribute_right_value: Attribute value, only required when `attribute_right_value_type` is `AttributeValue`
        :param builtins.str attribute_right_value_type: Advanced attribute value type
                 - Choices: `AdvancedDictionaryAttribute`, `AttributeValue`
        """
        if attribute_left_dictionary_name is not None:
            pulumi.set(__self__, "attribute_left_dictionary_name", attribute_left_dictionary_name)
        if attribute_left_name is not None:
            pulumi.set(__self__, "attribute_left_name", attribute_left_name)
        if attribute_right_dictionary_name is not None:
            pulumi.set(__self__, "attribute_right_dictionary_name", attribute_right_dictionary_name)
        if attribute_right_name is not None:
            pulumi.set(__self__, "attribute_right_name", attribute_right_name)
        if attribute_right_value is not None:
            pulumi.set(__self__, "attribute_right_value", attribute_right_value)
        if attribute_right_value_type is not None:
            pulumi.set(__self__, "attribute_right_value_type", attribute_right_value_type)

    @property
    @pulumi.getter(name="attributeLeftDictionaryName")
    def attribute_left_dictionary_name(self) -> Optional[builtins.str]:
        """
        Dictionary name
        """
        return pulumi.get(self, "attribute_left_dictionary_name")

    @property
    @pulumi.getter(name="attributeLeftName")
    def attribute_left_name(self) -> Optional[builtins.str]:
        """
        Attribute name
        """
        return pulumi.get(self, "attribute_left_name")

    @property
    @pulumi.getter(name="attributeRightDictionaryName")
    def attribute_right_dictionary_name(self) -> Optional[builtins.str]:
        """
        Dictionary name, only required when `attribute_right_value_type` is `AdvancedDictionaryAttribute`
        """
        return pulumi.get(self, "attribute_right_dictionary_name")

    @property
    @pulumi.getter(name="attributeRightName")
    def attribute_right_name(self) -> Optional[builtins.str]:
        """
        Attribute name, only required when `attribute_right_value_type` is `AdvancedDictionaryAttribute`
        """
        return pulumi.get(self, "attribute_right_name")

    @property
    @pulumi.getter(name="attributeRightValue")
    def attribute_right_value(self) -> Optional[builtins.str]:
        """
        Attribute value, only required when `attribute_right_value_type` is `AttributeValue`
        """
        return pulumi.get(self, "attribute_right_value")

    @property
    @pulumi.getter(name="attributeRightValueType")
    def attribute_right_value_type(self) -> Optional[builtins.str]:
        """
        Advanced attribute value type
          - Choices: `AdvancedDictionaryAttribute`, `AttributeValue`
        """
        return pulumi.get(self, "attribute_right_value_type")


@pulumi.output_type
class AuthorizationRuleChildren(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "conditionType":
            suggest = "condition_type"
        elif key == "attributeName":
            suggest = "attribute_name"
        elif key == "attributeValue":
            suggest = "attribute_value"
        elif key == "dictionaryName":
            suggest = "dictionary_name"
        elif key == "dictionaryValue":
            suggest = "dictionary_value"
        elif key == "isNegate":
            suggest = "is_negate"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in AuthorizationRuleChildren. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        AuthorizationRuleChildren.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        AuthorizationRuleChildren.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 condition_type: builtins.str,
                 attribute_name: Optional[builtins.str] = None,
                 attribute_value: Optional[builtins.str] = None,
                 childrens: Optional[Sequence['outputs.AuthorizationRuleChildrenChildren']] = None,
                 dictionary_name: Optional[builtins.str] = None,
                 dictionary_value: Optional[builtins.str] = None,
                 id: Optional[builtins.str] = None,
                 is_negate: Optional[builtins.bool] = None,
                 operator: Optional[builtins.str] = None):
        """
        :param builtins.str condition_type: Indicates whether the record is the condition itself or a logical aggregation. Logical aggreation indicates that additional conditions are present under the children attribute.
                 - Choices: `ConditionAndBlock`, `ConditionAttributes`, `ConditionOrBlock`, `ConditionReference`
        :param builtins.str attribute_name: Dictionary attribute name
        :param builtins.str attribute_value: Attribute value for condition. Value type is specified in dictionary object.
        :param Sequence['AuthorizationRuleChildrenChildrenArgs'] childrens: List of child conditions. `condition_type` must be one of `ConditionAndBlock` or `ConditionOrBlock`.
        :param builtins.str dictionary_name: Dictionary name
        :param builtins.str dictionary_value: Dictionary value
        :param builtins.str id: UUID for condition
        :param builtins.bool is_negate: Indicates whereas this condition is in negate mode
        :param builtins.str operator: Equality operator
                 - Choices: `contains`, `endsWith`, `equals`, `greaterOrEquals`, `greaterThan`, `in`, `ipEquals`, `ipGreaterThan`, `ipLessThan`, `ipNotEquals`, `lessOrEquals`, `lessThan`, `matches`, `notContains`, `notEndsWith`, `notEquals`, `notIn`, `notStartsWith`, `startsWith`
        """
        pulumi.set(__self__, "condition_type", condition_type)
        if attribute_name is not None:
            pulumi.set(__self__, "attribute_name", attribute_name)
        if attribute_value is not None:
            pulumi.set(__self__, "attribute_value", attribute_value)
        if childrens is not None:
            pulumi.set(__self__, "childrens", childrens)
        if dictionary_name is not None:
            pulumi.set(__self__, "dictionary_name", dictionary_name)
        if dictionary_value is not None:
            pulumi.set(__self__, "dictionary_value", dictionary_value)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if is_negate is not None:
            pulumi.set(__self__, "is_negate", is_negate)
        if operator is not None:
            pulumi.set(__self__, "operator", operator)

    @property
    @pulumi.getter(name="conditionType")
    def condition_type(self) -> builtins.str:
        """
        Indicates whether the record is the condition itself or a logical aggregation. Logical aggreation indicates that additional conditions are present under the children attribute.
          - Choices: `ConditionAndBlock`, `ConditionAttributes`, `ConditionOrBlock`, `ConditionReference`
        """
        return pulumi.get(self, "condition_type")

    @property
    @pulumi.getter(name="attributeName")
    def attribute_name(self) -> Optional[builtins.str]:
        """
        Dictionary attribute name
        """
        return pulumi.get(self, "attribute_name")

    @property
    @pulumi.getter(name="attributeValue")
    def attribute_value(self) -> Optional[builtins.str]:
        """
        Attribute value for condition. Value type is specified in dictionary object.
        """
        return pulumi.get(self, "attribute_value")

    @property
    @pulumi.getter
    def childrens(self) -> Optional[Sequence['outputs.AuthorizationRuleChildrenChildren']]:
        """
        List of child conditions. `condition_type` must be one of `ConditionAndBlock` or `ConditionOrBlock`.
        """
        return pulumi.get(self, "childrens")

    @property
    @pulumi.getter(name="dictionaryName")
    def dictionary_name(self) -> Optional[builtins.str]:
        """
        Dictionary name
        """
        return pulumi.get(self, "dictionary_name")

    @property
    @pulumi.getter(name="dictionaryValue")
    def dictionary_value(self) -> Optional[builtins.str]:
        """
        Dictionary value
        """
        return pulumi.get(self, "dictionary_value")

    @property
    @pulumi.getter
    def id(self) -> Optional[builtins.str]:
        """
        UUID for condition
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isNegate")
    def is_negate(self) -> Optional[builtins.bool]:
        """
        Indicates whereas this condition is in negate mode
        """
        return pulumi.get(self, "is_negate")

    @property
    @pulumi.getter
    def operator(self) -> Optional[builtins.str]:
        """
        Equality operator
          - Choices: `contains`, `endsWith`, `equals`, `greaterOrEquals`, `greaterThan`, `in`, `ipEquals`, `ipGreaterThan`, `ipLessThan`, `ipNotEquals`, `lessOrEquals`, `lessThan`, `matches`, `notContains`, `notEndsWith`, `notEquals`, `notIn`, `notStartsWith`, `startsWith`
        """
        return pulumi.get(self, "operator")


@pulumi.output_type
class AuthorizationRuleChildrenChildren(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "conditionType":
            suggest = "condition_type"
        elif key == "attributeName":
            suggest = "attribute_name"
        elif key == "attributeValue":
            suggest = "attribute_value"
        elif key == "dictionaryName":
            suggest = "dictionary_name"
        elif key == "dictionaryValue":
            suggest = "dictionary_value"
        elif key == "isNegate":
            suggest = "is_negate"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in AuthorizationRuleChildrenChildren. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        AuthorizationRuleChildrenChildren.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        AuthorizationRuleChildrenChildren.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 condition_type: builtins.str,
                 attribute_name: Optional[builtins.str] = None,
                 attribute_value: Optional[builtins.str] = None,
                 dictionary_name: Optional[builtins.str] = None,
                 dictionary_value: Optional[builtins.str] = None,
                 id: Optional[builtins.str] = None,
                 is_negate: Optional[builtins.bool] = None,
                 operator: Optional[builtins.str] = None):
        """
        :param builtins.str condition_type: Condition type.
                 - Choices: `ConditionAttributes`, `ConditionReference`
        :param builtins.str attribute_name: Dictionary attribute name
        :param builtins.str attribute_value: Attribute value for condition. Value type is specified in dictionary object.
        :param builtins.str dictionary_name: Dictionary name
        :param builtins.str dictionary_value: Dictionary value
        :param builtins.str id: UUID for condition
        :param builtins.bool is_negate: Indicates whereas this condition is in negate mode
        :param builtins.str operator: Equality operator
                 - Choices: `contains`, `endsWith`, `equals`, `greaterOrEquals`, `greaterThan`, `in`, `ipEquals`, `ipGreaterThan`, `ipLessThan`, `ipNotEquals`, `lessOrEquals`, `lessThan`, `matches`, `notContains`, `notEndsWith`, `notEquals`, `notIn`, `notStartsWith`, `startsWith`
        """
        pulumi.set(__self__, "condition_type", condition_type)
        if attribute_name is not None:
            pulumi.set(__self__, "attribute_name", attribute_name)
        if attribute_value is not None:
            pulumi.set(__self__, "attribute_value", attribute_value)
        if dictionary_name is not None:
            pulumi.set(__self__, "dictionary_name", dictionary_name)
        if dictionary_value is not None:
            pulumi.set(__self__, "dictionary_value", dictionary_value)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if is_negate is not None:
            pulumi.set(__self__, "is_negate", is_negate)
        if operator is not None:
            pulumi.set(__self__, "operator", operator)

    @property
    @pulumi.getter(name="conditionType")
    def condition_type(self) -> builtins.str:
        """
        Condition type.
          - Choices: `ConditionAttributes`, `ConditionReference`
        """
        return pulumi.get(self, "condition_type")

    @property
    @pulumi.getter(name="attributeName")
    def attribute_name(self) -> Optional[builtins.str]:
        """
        Dictionary attribute name
        """
        return pulumi.get(self, "attribute_name")

    @property
    @pulumi.getter(name="attributeValue")
    def attribute_value(self) -> Optional[builtins.str]:
        """
        Attribute value for condition. Value type is specified in dictionary object.
        """
        return pulumi.get(self, "attribute_value")

    @property
    @pulumi.getter(name="dictionaryName")
    def dictionary_name(self) -> Optional[builtins.str]:
        """
        Dictionary name
        """
        return pulumi.get(self, "dictionary_name")

    @property
    @pulumi.getter(name="dictionaryValue")
    def dictionary_value(self) -> Optional[builtins.str]:
        """
        Dictionary value
        """
        return pulumi.get(self, "dictionary_value")

    @property
    @pulumi.getter
    def id(self) -> Optional[builtins.str]:
        """
        UUID for condition
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isNegate")
    def is_negate(self) -> Optional[builtins.bool]:
        """
        Indicates whereas this condition is in negate mode
        """
        return pulumi.get(self, "is_negate")

    @property
    @pulumi.getter
    def operator(self) -> Optional[builtins.str]:
        """
        Equality operator
          - Choices: `contains`, `endsWith`, `equals`, `greaterOrEquals`, `greaterThan`, `in`, `ipEquals`, `ipGreaterThan`, `ipLessThan`, `ipNotEquals`, `lessOrEquals`, `lessThan`, `matches`, `notContains`, `notEndsWith`, `notEquals`, `notIn`, `notStartsWith`, `startsWith`
        """
        return pulumi.get(self, "operator")


@pulumi.output_type
class ConditionChildren(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "conditionType":
            suggest = "condition_type"
        elif key == "attributeName":
            suggest = "attribute_name"
        elif key == "attributeValue":
            suggest = "attribute_value"
        elif key == "dictionaryName":
            suggest = "dictionary_name"
        elif key == "dictionaryValue":
            suggest = "dictionary_value"
        elif key == "isNegate":
            suggest = "is_negate"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ConditionChildren. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ConditionChildren.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ConditionChildren.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 condition_type: builtins.str,
                 attribute_name: Optional[builtins.str] = None,
                 attribute_value: Optional[builtins.str] = None,
                 childrens: Optional[Sequence['outputs.ConditionChildrenChildren']] = None,
                 description: Optional[builtins.str] = None,
                 dictionary_name: Optional[builtins.str] = None,
                 dictionary_value: Optional[builtins.str] = None,
                 id: Optional[builtins.str] = None,
                 is_negate: Optional[builtins.bool] = None,
                 name: Optional[builtins.str] = None,
                 operator: Optional[builtins.str] = None):
        """
        :param builtins.str condition_type: Indicates whether the record is the condition itself or a logical aggregation. Logical aggreation indicates that additional conditions are present under the children attribute.
                 - Choices: `ConditionAndBlock`, `ConditionAttributes`, `ConditionOrBlock`, `ConditionReference`
        :param builtins.str attribute_name: Dictionary attribute name
        :param builtins.str attribute_value: Attribute value for condition. Value type is specified in dictionary object.
        :param Sequence['ConditionChildrenChildrenArgs'] childrens: List of child conditions. `condition_type` must be one of `ConditionAndBlock` or `ConditionOrBlock`.
        :param builtins.str description: Condition description
        :param builtins.str dictionary_name: Dictionary name
        :param builtins.str dictionary_value: Dictionary value
        :param builtins.str id: UUID for condition
        :param builtins.bool is_negate: Indicates whereas this condition is in negate mode
        :param builtins.str name: Condition name
        :param builtins.str operator: Equality operator
                 - Choices: `contains`, `endsWith`, `equals`, `greaterOrEquals`, `greaterThan`, `in`, `ipEquals`, `ipGreaterThan`, `ipLessThan`, `ipNotEquals`, `lessOrEquals`, `lessThan`, `matches`, `notContains`, `notEndsWith`, `notEquals`, `notIn`, `notStartsWith`, `startsWith`
        """
        pulumi.set(__self__, "condition_type", condition_type)
        if attribute_name is not None:
            pulumi.set(__self__, "attribute_name", attribute_name)
        if attribute_value is not None:
            pulumi.set(__self__, "attribute_value", attribute_value)
        if childrens is not None:
            pulumi.set(__self__, "childrens", childrens)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if dictionary_name is not None:
            pulumi.set(__self__, "dictionary_name", dictionary_name)
        if dictionary_value is not None:
            pulumi.set(__self__, "dictionary_value", dictionary_value)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if is_negate is not None:
            pulumi.set(__self__, "is_negate", is_negate)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if operator is not None:
            pulumi.set(__self__, "operator", operator)

    @property
    @pulumi.getter(name="conditionType")
    def condition_type(self) -> builtins.str:
        """
        Indicates whether the record is the condition itself or a logical aggregation. Logical aggreation indicates that additional conditions are present under the children attribute.
          - Choices: `ConditionAndBlock`, `ConditionAttributes`, `ConditionOrBlock`, `ConditionReference`
        """
        return pulumi.get(self, "condition_type")

    @property
    @pulumi.getter(name="attributeName")
    def attribute_name(self) -> Optional[builtins.str]:
        """
        Dictionary attribute name
        """
        return pulumi.get(self, "attribute_name")

    @property
    @pulumi.getter(name="attributeValue")
    def attribute_value(self) -> Optional[builtins.str]:
        """
        Attribute value for condition. Value type is specified in dictionary object.
        """
        return pulumi.get(self, "attribute_value")

    @property
    @pulumi.getter
    def childrens(self) -> Optional[Sequence['outputs.ConditionChildrenChildren']]:
        """
        List of child conditions. `condition_type` must be one of `ConditionAndBlock` or `ConditionOrBlock`.
        """
        return pulumi.get(self, "childrens")

    @property
    @pulumi.getter
    def description(self) -> Optional[builtins.str]:
        """
        Condition description
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="dictionaryName")
    def dictionary_name(self) -> Optional[builtins.str]:
        """
        Dictionary name
        """
        return pulumi.get(self, "dictionary_name")

    @property
    @pulumi.getter(name="dictionaryValue")
    def dictionary_value(self) -> Optional[builtins.str]:
        """
        Dictionary value
        """
        return pulumi.get(self, "dictionary_value")

    @property
    @pulumi.getter
    def id(self) -> Optional[builtins.str]:
        """
        UUID for condition
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isNegate")
    def is_negate(self) -> Optional[builtins.bool]:
        """
        Indicates whereas this condition is in negate mode
        """
        return pulumi.get(self, "is_negate")

    @property
    @pulumi.getter
    def name(self) -> Optional[builtins.str]:
        """
        Condition name
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def operator(self) -> Optional[builtins.str]:
        """
        Equality operator
          - Choices: `contains`, `endsWith`, `equals`, `greaterOrEquals`, `greaterThan`, `in`, `ipEquals`, `ipGreaterThan`, `ipLessThan`, `ipNotEquals`, `lessOrEquals`, `lessThan`, `matches`, `notContains`, `notEndsWith`, `notEquals`, `notIn`, `notStartsWith`, `startsWith`
        """
        return pulumi.get(self, "operator")


@pulumi.output_type
class ConditionChildrenChildren(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "conditionType":
            suggest = "condition_type"
        elif key == "attributeName":
            suggest = "attribute_name"
        elif key == "attributeValue":
            suggest = "attribute_value"
        elif key == "dictionaryName":
            suggest = "dictionary_name"
        elif key == "dictionaryValue":
            suggest = "dictionary_value"
        elif key == "isNegate":
            suggest = "is_negate"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ConditionChildrenChildren. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ConditionChildrenChildren.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ConditionChildrenChildren.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 condition_type: builtins.str,
                 attribute_name: Optional[builtins.str] = None,
                 attribute_value: Optional[builtins.str] = None,
                 description: Optional[builtins.str] = None,
                 dictionary_name: Optional[builtins.str] = None,
                 dictionary_value: Optional[builtins.str] = None,
                 id: Optional[builtins.str] = None,
                 is_negate: Optional[builtins.bool] = None,
                 name: Optional[builtins.str] = None,
                 operator: Optional[builtins.str] = None):
        """
        :param builtins.str condition_type: Condition type.
                 - Choices: `ConditionAttributes`, `ConditionReference`
        :param builtins.str attribute_name: Dictionary attribute name
        :param builtins.str attribute_value: Attribute value for condition. Value type is specified in dictionary object.
        :param builtins.str description: Condition description
        :param builtins.str dictionary_name: Dictionary name
        :param builtins.str dictionary_value: Dictionary value
        :param builtins.str id: UUID for condition
        :param builtins.bool is_negate: Indicates whereas this condition is in negate mode
        :param builtins.str name: Condition name
        :param builtins.str operator: Equality operator
                 - Choices: `contains`, `endsWith`, `equals`, `greaterOrEquals`, `greaterThan`, `in`, `ipEquals`, `ipGreaterThan`, `ipLessThan`, `ipNotEquals`, `lessOrEquals`, `lessThan`, `matches`, `notContains`, `notEndsWith`, `notEquals`, `notIn`, `notStartsWith`, `startsWith`
        """
        pulumi.set(__self__, "condition_type", condition_type)
        if attribute_name is not None:
            pulumi.set(__self__, "attribute_name", attribute_name)
        if attribute_value is not None:
            pulumi.set(__self__, "attribute_value", attribute_value)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if dictionary_name is not None:
            pulumi.set(__self__, "dictionary_name", dictionary_name)
        if dictionary_value is not None:
            pulumi.set(__self__, "dictionary_value", dictionary_value)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if is_negate is not None:
            pulumi.set(__self__, "is_negate", is_negate)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if operator is not None:
            pulumi.set(__self__, "operator", operator)

    @property
    @pulumi.getter(name="conditionType")
    def condition_type(self) -> builtins.str:
        """
        Condition type.
          - Choices: `ConditionAttributes`, `ConditionReference`
        """
        return pulumi.get(self, "condition_type")

    @property
    @pulumi.getter(name="attributeName")
    def attribute_name(self) -> Optional[builtins.str]:
        """
        Dictionary attribute name
        """
        return pulumi.get(self, "attribute_name")

    @property
    @pulumi.getter(name="attributeValue")
    def attribute_value(self) -> Optional[builtins.str]:
        """
        Attribute value for condition. Value type is specified in dictionary object.
        """
        return pulumi.get(self, "attribute_value")

    @property
    @pulumi.getter
    def description(self) -> Optional[builtins.str]:
        """
        Condition description
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="dictionaryName")
    def dictionary_name(self) -> Optional[builtins.str]:
        """
        Dictionary name
        """
        return pulumi.get(self, "dictionary_name")

    @property
    @pulumi.getter(name="dictionaryValue")
    def dictionary_value(self) -> Optional[builtins.str]:
        """
        Dictionary value
        """
        return pulumi.get(self, "dictionary_value")

    @property
    @pulumi.getter
    def id(self) -> Optional[builtins.str]:
        """
        UUID for condition
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isNegate")
    def is_negate(self) -> Optional[builtins.bool]:
        """
        Indicates whereas this condition is in negate mode
        """
        return pulumi.get(self, "is_negate")

    @property
    @pulumi.getter
    def name(self) -> Optional[builtins.str]:
        """
        Condition name
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def operator(self) -> Optional[builtins.str]:
        """
        Equality operator
          - Choices: `contains`, `endsWith`, `equals`, `greaterOrEquals`, `greaterThan`, `in`, `ipEquals`, `ipGreaterThan`, `ipLessThan`, `ipNotEquals`, `lessOrEquals`, `lessThan`, `matches`, `notContains`, `notEndsWith`, `notEquals`, `notIn`, `notStartsWith`, `startsWith`
        """
        return pulumi.get(self, "operator")


@pulumi.output_type
class PolicySetChildren(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "conditionType":
            suggest = "condition_type"
        elif key == "attributeName":
            suggest = "attribute_name"
        elif key == "attributeValue":
            suggest = "attribute_value"
        elif key == "dictionaryName":
            suggest = "dictionary_name"
        elif key == "dictionaryValue":
            suggest = "dictionary_value"
        elif key == "isNegate":
            suggest = "is_negate"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in PolicySetChildren. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        PolicySetChildren.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        PolicySetChildren.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 condition_type: builtins.str,
                 attribute_name: Optional[builtins.str] = None,
                 attribute_value: Optional[builtins.str] = None,
                 childrens: Optional[Sequence['outputs.PolicySetChildrenChildren']] = None,
                 dictionary_name: Optional[builtins.str] = None,
                 dictionary_value: Optional[builtins.str] = None,
                 id: Optional[builtins.str] = None,
                 is_negate: Optional[builtins.bool] = None,
                 operator: Optional[builtins.str] = None):
        """
        :param builtins.str condition_type: Indicates whether the record is the condition itself or a logical aggregation. Logical aggreation indicates that additional conditions are present under the children attribute.
                 - Choices: `ConditionAndBlock`, `ConditionAttributes`, `ConditionOrBlock`, `ConditionReference`
        :param builtins.str attribute_name: Dictionary attribute name
        :param builtins.str attribute_value: Attribute value for condition. Value type is specified in dictionary object.
        :param Sequence['PolicySetChildrenChildrenArgs'] childrens: List of child conditions. `condition_type` must be one of `ConditionAndBlock` or `ConditionOrBlock`.
        :param builtins.str dictionary_name: Dictionary name
        :param builtins.str dictionary_value: Dictionary value
        :param builtins.str id: UUID for condition
        :param builtins.bool is_negate: Indicates whereas this condition is in negate mode
        :param builtins.str operator: Equality operator
                 - Choices: `contains`, `endsWith`, `equals`, `greaterOrEquals`, `greaterThan`, `in`, `ipEquals`, `ipGreaterThan`, `ipLessThan`, `ipNotEquals`, `lessOrEquals`, `lessThan`, `matches`, `notContains`, `notEndsWith`, `notEquals`, `notIn`, `notStartsWith`, `startsWith`
        """
        pulumi.set(__self__, "condition_type", condition_type)
        if attribute_name is not None:
            pulumi.set(__self__, "attribute_name", attribute_name)
        if attribute_value is not None:
            pulumi.set(__self__, "attribute_value", attribute_value)
        if childrens is not None:
            pulumi.set(__self__, "childrens", childrens)
        if dictionary_name is not None:
            pulumi.set(__self__, "dictionary_name", dictionary_name)
        if dictionary_value is not None:
            pulumi.set(__self__, "dictionary_value", dictionary_value)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if is_negate is not None:
            pulumi.set(__self__, "is_negate", is_negate)
        if operator is not None:
            pulumi.set(__self__, "operator", operator)

    @property
    @pulumi.getter(name="conditionType")
    def condition_type(self) -> builtins.str:
        """
        Indicates whether the record is the condition itself or a logical aggregation. Logical aggreation indicates that additional conditions are present under the children attribute.
          - Choices: `ConditionAndBlock`, `ConditionAttributes`, `ConditionOrBlock`, `ConditionReference`
        """
        return pulumi.get(self, "condition_type")

    @property
    @pulumi.getter(name="attributeName")
    def attribute_name(self) -> Optional[builtins.str]:
        """
        Dictionary attribute name
        """
        return pulumi.get(self, "attribute_name")

    @property
    @pulumi.getter(name="attributeValue")
    def attribute_value(self) -> Optional[builtins.str]:
        """
        Attribute value for condition. Value type is specified in dictionary object.
        """
        return pulumi.get(self, "attribute_value")

    @property
    @pulumi.getter
    def childrens(self) -> Optional[Sequence['outputs.PolicySetChildrenChildren']]:
        """
        List of child conditions. `condition_type` must be one of `ConditionAndBlock` or `ConditionOrBlock`.
        """
        return pulumi.get(self, "childrens")

    @property
    @pulumi.getter(name="dictionaryName")
    def dictionary_name(self) -> Optional[builtins.str]:
        """
        Dictionary name
        """
        return pulumi.get(self, "dictionary_name")

    @property
    @pulumi.getter(name="dictionaryValue")
    def dictionary_value(self) -> Optional[builtins.str]:
        """
        Dictionary value
        """
        return pulumi.get(self, "dictionary_value")

    @property
    @pulumi.getter
    def id(self) -> Optional[builtins.str]:
        """
        UUID for condition
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isNegate")
    def is_negate(self) -> Optional[builtins.bool]:
        """
        Indicates whereas this condition is in negate mode
        """
        return pulumi.get(self, "is_negate")

    @property
    @pulumi.getter
    def operator(self) -> Optional[builtins.str]:
        """
        Equality operator
          - Choices: `contains`, `endsWith`, `equals`, `greaterOrEquals`, `greaterThan`, `in`, `ipEquals`, `ipGreaterThan`, `ipLessThan`, `ipNotEquals`, `lessOrEquals`, `lessThan`, `matches`, `notContains`, `notEndsWith`, `notEquals`, `notIn`, `notStartsWith`, `startsWith`
        """
        return pulumi.get(self, "operator")


@pulumi.output_type
class PolicySetChildrenChildren(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "conditionType":
            suggest = "condition_type"
        elif key == "attributeName":
            suggest = "attribute_name"
        elif key == "attributeValue":
            suggest = "attribute_value"
        elif key == "dictionaryName":
            suggest = "dictionary_name"
        elif key == "dictionaryValue":
            suggest = "dictionary_value"
        elif key == "isNegate":
            suggest = "is_negate"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in PolicySetChildrenChildren. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        PolicySetChildrenChildren.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        PolicySetChildrenChildren.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 condition_type: builtins.str,
                 attribute_name: Optional[builtins.str] = None,
                 attribute_value: Optional[builtins.str] = None,
                 dictionary_name: Optional[builtins.str] = None,
                 dictionary_value: Optional[builtins.str] = None,
                 id: Optional[builtins.str] = None,
                 is_negate: Optional[builtins.bool] = None,
                 operator: Optional[builtins.str] = None):
        """
        :param builtins.str condition_type: Condition type.
                 - Choices: `ConditionAttributes`, `ConditionReference`
        :param builtins.str attribute_name: Dictionary attribute name
        :param builtins.str attribute_value: Attribute value for condition. Value type is specified in dictionary object.
        :param builtins.str dictionary_name: Dictionary name
        :param builtins.str dictionary_value: Dictionary value
        :param builtins.str id: UUID for condition
        :param builtins.bool is_negate: Indicates whereas this condition is in negate mode
        :param builtins.str operator: Equality operator
                 - Choices: `contains`, `endsWith`, `equals`, `greaterOrEquals`, `greaterThan`, `in`, `ipEquals`, `ipGreaterThan`, `ipLessThan`, `ipNotEquals`, `lessOrEquals`, `lessThan`, `matches`, `notContains`, `notEndsWith`, `notEquals`, `notIn`, `notStartsWith`, `startsWith`
        """
        pulumi.set(__self__, "condition_type", condition_type)
        if attribute_name is not None:
            pulumi.set(__self__, "attribute_name", attribute_name)
        if attribute_value is not None:
            pulumi.set(__self__, "attribute_value", attribute_value)
        if dictionary_name is not None:
            pulumi.set(__self__, "dictionary_name", dictionary_name)
        if dictionary_value is not None:
            pulumi.set(__self__, "dictionary_value", dictionary_value)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if is_negate is not None:
            pulumi.set(__self__, "is_negate", is_negate)
        if operator is not None:
            pulumi.set(__self__, "operator", operator)

    @property
    @pulumi.getter(name="conditionType")
    def condition_type(self) -> builtins.str:
        """
        Condition type.
          - Choices: `ConditionAttributes`, `ConditionReference`
        """
        return pulumi.get(self, "condition_type")

    @property
    @pulumi.getter(name="attributeName")
    def attribute_name(self) -> Optional[builtins.str]:
        """
        Dictionary attribute name
        """
        return pulumi.get(self, "attribute_name")

    @property
    @pulumi.getter(name="attributeValue")
    def attribute_value(self) -> Optional[builtins.str]:
        """
        Attribute value for condition. Value type is specified in dictionary object.
        """
        return pulumi.get(self, "attribute_value")

    @property
    @pulumi.getter(name="dictionaryName")
    def dictionary_name(self) -> Optional[builtins.str]:
        """
        Dictionary name
        """
        return pulumi.get(self, "dictionary_name")

    @property
    @pulumi.getter(name="dictionaryValue")
    def dictionary_value(self) -> Optional[builtins.str]:
        """
        Dictionary value
        """
        return pulumi.get(self, "dictionary_value")

    @property
    @pulumi.getter
    def id(self) -> Optional[builtins.str]:
        """
        UUID for condition
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isNegate")
    def is_negate(self) -> Optional[builtins.bool]:
        """
        Indicates whereas this condition is in negate mode
        """
        return pulumi.get(self, "is_negate")

    @property
    @pulumi.getter
    def operator(self) -> Optional[builtins.str]:
        """
        Equality operator
          - Choices: `contains`, `endsWith`, `equals`, `greaterOrEquals`, `greaterThan`, `in`, `ipEquals`, `ipGreaterThan`, `ipLessThan`, `ipNotEquals`, `lessOrEquals`, `lessThan`, `matches`, `notContains`, `notEndsWith`, `notEquals`, `notIn`, `notStartsWith`, `startsWith`
        """
        return pulumi.get(self, "operator")


@pulumi.output_type
class GetAuthenticationRuleChildrenResult(dict):
    def __init__(__self__, *,
                 attribute_name: builtins.str,
                 attribute_value: builtins.str,
                 childrens: Sequence['outputs.GetAuthenticationRuleChildrenChildrenResult'],
                 condition_type: builtins.str,
                 dictionary_name: builtins.str,
                 dictionary_value: builtins.str,
                 id: builtins.str,
                 is_negate: builtins.bool,
                 operator: builtins.str):
        """
        :param builtins.str attribute_name: Dictionary attribute name
        :param builtins.str attribute_value: Attribute value for condition. Value type is specified in dictionary object.
        :param Sequence['GetAuthenticationRuleChildrenChildrenArgs'] childrens: List of child conditions. `condition_type` must be one of `ConditionAndBlock` or `ConditionOrBlock`.
        :param builtins.str condition_type: Indicates whether the record is the condition itself or a logical aggregation. Logical aggreation indicates that additional conditions are present under the children attribute.
        :param builtins.str dictionary_name: Dictionary name
        :param builtins.str dictionary_value: Dictionary value
        :param builtins.str id: UUID for condition
        :param builtins.bool is_negate: Indicates whereas this condition is in negate mode
        :param builtins.str operator: Equality operator
        """
        pulumi.set(__self__, "attribute_name", attribute_name)
        pulumi.set(__self__, "attribute_value", attribute_value)
        pulumi.set(__self__, "childrens", childrens)
        pulumi.set(__self__, "condition_type", condition_type)
        pulumi.set(__self__, "dictionary_name", dictionary_name)
        pulumi.set(__self__, "dictionary_value", dictionary_value)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "is_negate", is_negate)
        pulumi.set(__self__, "operator", operator)

    @property
    @pulumi.getter(name="attributeName")
    def attribute_name(self) -> builtins.str:
        """
        Dictionary attribute name
        """
        return pulumi.get(self, "attribute_name")

    @property
    @pulumi.getter(name="attributeValue")
    def attribute_value(self) -> builtins.str:
        """
        Attribute value for condition. Value type is specified in dictionary object.
        """
        return pulumi.get(self, "attribute_value")

    @property
    @pulumi.getter
    def childrens(self) -> Sequence['outputs.GetAuthenticationRuleChildrenChildrenResult']:
        """
        List of child conditions. `condition_type` must be one of `ConditionAndBlock` or `ConditionOrBlock`.
        """
        return pulumi.get(self, "childrens")

    @property
    @pulumi.getter(name="conditionType")
    def condition_type(self) -> builtins.str:
        """
        Indicates whether the record is the condition itself or a logical aggregation. Logical aggreation indicates that additional conditions are present under the children attribute.
        """
        return pulumi.get(self, "condition_type")

    @property
    @pulumi.getter(name="dictionaryName")
    def dictionary_name(self) -> builtins.str:
        """
        Dictionary name
        """
        return pulumi.get(self, "dictionary_name")

    @property
    @pulumi.getter(name="dictionaryValue")
    def dictionary_value(self) -> builtins.str:
        """
        Dictionary value
        """
        return pulumi.get(self, "dictionary_value")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        UUID for condition
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isNegate")
    def is_negate(self) -> builtins.bool:
        """
        Indicates whereas this condition is in negate mode
        """
        return pulumi.get(self, "is_negate")

    @property
    @pulumi.getter
    def operator(self) -> builtins.str:
        """
        Equality operator
        """
        return pulumi.get(self, "operator")


@pulumi.output_type
class GetAuthenticationRuleChildrenChildrenResult(dict):
    def __init__(__self__, *,
                 attribute_name: builtins.str,
                 attribute_value: builtins.str,
                 condition_type: builtins.str,
                 dictionary_name: builtins.str,
                 dictionary_value: builtins.str,
                 id: builtins.str,
                 is_negate: builtins.bool,
                 operator: builtins.str):
        """
        :param builtins.str attribute_name: Dictionary attribute name
        :param builtins.str attribute_value: Attribute value for condition. Value type is specified in dictionary object.
        :param builtins.str condition_type: Condition type.
        :param builtins.str dictionary_name: Dictionary name
        :param builtins.str dictionary_value: Dictionary value
        :param builtins.str id: UUID for condition
        :param builtins.bool is_negate: Indicates whereas this condition is in negate mode
        :param builtins.str operator: Equality operator
        """
        pulumi.set(__self__, "attribute_name", attribute_name)
        pulumi.set(__self__, "attribute_value", attribute_value)
        pulumi.set(__self__, "condition_type", condition_type)
        pulumi.set(__self__, "dictionary_name", dictionary_name)
        pulumi.set(__self__, "dictionary_value", dictionary_value)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "is_negate", is_negate)
        pulumi.set(__self__, "operator", operator)

    @property
    @pulumi.getter(name="attributeName")
    def attribute_name(self) -> builtins.str:
        """
        Dictionary attribute name
        """
        return pulumi.get(self, "attribute_name")

    @property
    @pulumi.getter(name="attributeValue")
    def attribute_value(self) -> builtins.str:
        """
        Attribute value for condition. Value type is specified in dictionary object.
        """
        return pulumi.get(self, "attribute_value")

    @property
    @pulumi.getter(name="conditionType")
    def condition_type(self) -> builtins.str:
        """
        Condition type.
        """
        return pulumi.get(self, "condition_type")

    @property
    @pulumi.getter(name="dictionaryName")
    def dictionary_name(self) -> builtins.str:
        """
        Dictionary name
        """
        return pulumi.get(self, "dictionary_name")

    @property
    @pulumi.getter(name="dictionaryValue")
    def dictionary_value(self) -> builtins.str:
        """
        Dictionary value
        """
        return pulumi.get(self, "dictionary_value")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        UUID for condition
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isNegate")
    def is_negate(self) -> builtins.bool:
        """
        Indicates whereas this condition is in negate mode
        """
        return pulumi.get(self, "is_negate")

    @property
    @pulumi.getter
    def operator(self) -> builtins.str:
        """
        Equality operator
        """
        return pulumi.get(self, "operator")


@pulumi.output_type
class GetAuthorizationExceptionRuleChildrenResult(dict):
    def __init__(__self__, *,
                 attribute_name: builtins.str,
                 attribute_value: builtins.str,
                 childrens: Sequence['outputs.GetAuthorizationExceptionRuleChildrenChildrenResult'],
                 condition_type: builtins.str,
                 dictionary_name: builtins.str,
                 dictionary_value: builtins.str,
                 id: builtins.str,
                 is_negate: builtins.bool,
                 operator: builtins.str):
        """
        :param builtins.str attribute_name: Dictionary attribute name
        :param builtins.str attribute_value: Attribute value for condition. Value type is specified in dictionary object.
        :param Sequence['GetAuthorizationExceptionRuleChildrenChildrenArgs'] childrens: List of child conditions. `condition_type` must be one of `ConditionAndBlock` or `ConditionOrBlock`.
        :param builtins.str condition_type: Indicates whether the record is the condition itself or a logical aggregation. Logical aggreation indicates that additional conditions are present under the children attribute.
        :param builtins.str dictionary_name: Dictionary name
        :param builtins.str dictionary_value: Dictionary value
        :param builtins.str id: UUID for condition
        :param builtins.bool is_negate: Indicates whereas this condition is in negate mode
        :param builtins.str operator: Equality operator
        """
        pulumi.set(__self__, "attribute_name", attribute_name)
        pulumi.set(__self__, "attribute_value", attribute_value)
        pulumi.set(__self__, "childrens", childrens)
        pulumi.set(__self__, "condition_type", condition_type)
        pulumi.set(__self__, "dictionary_name", dictionary_name)
        pulumi.set(__self__, "dictionary_value", dictionary_value)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "is_negate", is_negate)
        pulumi.set(__self__, "operator", operator)

    @property
    @pulumi.getter(name="attributeName")
    def attribute_name(self) -> builtins.str:
        """
        Dictionary attribute name
        """
        return pulumi.get(self, "attribute_name")

    @property
    @pulumi.getter(name="attributeValue")
    def attribute_value(self) -> builtins.str:
        """
        Attribute value for condition. Value type is specified in dictionary object.
        """
        return pulumi.get(self, "attribute_value")

    @property
    @pulumi.getter
    def childrens(self) -> Sequence['outputs.GetAuthorizationExceptionRuleChildrenChildrenResult']:
        """
        List of child conditions. `condition_type` must be one of `ConditionAndBlock` or `ConditionOrBlock`.
        """
        return pulumi.get(self, "childrens")

    @property
    @pulumi.getter(name="conditionType")
    def condition_type(self) -> builtins.str:
        """
        Indicates whether the record is the condition itself or a logical aggregation. Logical aggreation indicates that additional conditions are present under the children attribute.
        """
        return pulumi.get(self, "condition_type")

    @property
    @pulumi.getter(name="dictionaryName")
    def dictionary_name(self) -> builtins.str:
        """
        Dictionary name
        """
        return pulumi.get(self, "dictionary_name")

    @property
    @pulumi.getter(name="dictionaryValue")
    def dictionary_value(self) -> builtins.str:
        """
        Dictionary value
        """
        return pulumi.get(self, "dictionary_value")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        UUID for condition
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isNegate")
    def is_negate(self) -> builtins.bool:
        """
        Indicates whereas this condition is in negate mode
        """
        return pulumi.get(self, "is_negate")

    @property
    @pulumi.getter
    def operator(self) -> builtins.str:
        """
        Equality operator
        """
        return pulumi.get(self, "operator")


@pulumi.output_type
class GetAuthorizationExceptionRuleChildrenChildrenResult(dict):
    def __init__(__self__, *,
                 attribute_name: builtins.str,
                 attribute_value: builtins.str,
                 condition_type: builtins.str,
                 dictionary_name: builtins.str,
                 dictionary_value: builtins.str,
                 id: builtins.str,
                 is_negate: builtins.bool,
                 operator: builtins.str):
        """
        :param builtins.str attribute_name: Dictionary attribute name
        :param builtins.str attribute_value: Attribute value for condition. Value type is specified in dictionary object.
        :param builtins.str condition_type: Condition type.
        :param builtins.str dictionary_name: Dictionary name
        :param builtins.str dictionary_value: Dictionary value
        :param builtins.str id: UUID for condition
        :param builtins.bool is_negate: Indicates whereas this condition is in negate mode
        :param builtins.str operator: Equality operator
        """
        pulumi.set(__self__, "attribute_name", attribute_name)
        pulumi.set(__self__, "attribute_value", attribute_value)
        pulumi.set(__self__, "condition_type", condition_type)
        pulumi.set(__self__, "dictionary_name", dictionary_name)
        pulumi.set(__self__, "dictionary_value", dictionary_value)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "is_negate", is_negate)
        pulumi.set(__self__, "operator", operator)

    @property
    @pulumi.getter(name="attributeName")
    def attribute_name(self) -> builtins.str:
        """
        Dictionary attribute name
        """
        return pulumi.get(self, "attribute_name")

    @property
    @pulumi.getter(name="attributeValue")
    def attribute_value(self) -> builtins.str:
        """
        Attribute value for condition. Value type is specified in dictionary object.
        """
        return pulumi.get(self, "attribute_value")

    @property
    @pulumi.getter(name="conditionType")
    def condition_type(self) -> builtins.str:
        """
        Condition type.
        """
        return pulumi.get(self, "condition_type")

    @property
    @pulumi.getter(name="dictionaryName")
    def dictionary_name(self) -> builtins.str:
        """
        Dictionary name
        """
        return pulumi.get(self, "dictionary_name")

    @property
    @pulumi.getter(name="dictionaryValue")
    def dictionary_value(self) -> builtins.str:
        """
        Dictionary value
        """
        return pulumi.get(self, "dictionary_value")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        UUID for condition
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isNegate")
    def is_negate(self) -> builtins.bool:
        """
        Indicates whereas this condition is in negate mode
        """
        return pulumi.get(self, "is_negate")

    @property
    @pulumi.getter
    def operator(self) -> builtins.str:
        """
        Equality operator
        """
        return pulumi.get(self, "operator")


@pulumi.output_type
class GetAuthorizationGlobalExceptionRuleChildrenResult(dict):
    def __init__(__self__, *,
                 attribute_name: builtins.str,
                 attribute_value: builtins.str,
                 childrens: Sequence['outputs.GetAuthorizationGlobalExceptionRuleChildrenChildrenResult'],
                 condition_type: builtins.str,
                 dictionary_name: builtins.str,
                 dictionary_value: builtins.str,
                 id: builtins.str,
                 is_negate: builtins.bool,
                 operator: builtins.str):
        """
        :param builtins.str attribute_name: Dictionary attribute name
        :param builtins.str attribute_value: Attribute value for condition. Value type is specified in dictionary object.
        :param Sequence['GetAuthorizationGlobalExceptionRuleChildrenChildrenArgs'] childrens: List of child conditions. `condition_type` must be one of `ConditionAndBlock` or `ConditionOrBlock`.
        :param builtins.str condition_type: Indicates whether the record is the condition itself or a logical aggregation. Logical aggreation indicates that additional conditions are present under the children attribute.
        :param builtins.str dictionary_name: Dictionary name
        :param builtins.str dictionary_value: Dictionary value
        :param builtins.str id: UUID for condition
        :param builtins.bool is_negate: Indicates whereas this condition is in negate mode
        :param builtins.str operator: Equality operator
        """
        pulumi.set(__self__, "attribute_name", attribute_name)
        pulumi.set(__self__, "attribute_value", attribute_value)
        pulumi.set(__self__, "childrens", childrens)
        pulumi.set(__self__, "condition_type", condition_type)
        pulumi.set(__self__, "dictionary_name", dictionary_name)
        pulumi.set(__self__, "dictionary_value", dictionary_value)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "is_negate", is_negate)
        pulumi.set(__self__, "operator", operator)

    @property
    @pulumi.getter(name="attributeName")
    def attribute_name(self) -> builtins.str:
        """
        Dictionary attribute name
        """
        return pulumi.get(self, "attribute_name")

    @property
    @pulumi.getter(name="attributeValue")
    def attribute_value(self) -> builtins.str:
        """
        Attribute value for condition. Value type is specified in dictionary object.
        """
        return pulumi.get(self, "attribute_value")

    @property
    @pulumi.getter
    def childrens(self) -> Sequence['outputs.GetAuthorizationGlobalExceptionRuleChildrenChildrenResult']:
        """
        List of child conditions. `condition_type` must be one of `ConditionAndBlock` or `ConditionOrBlock`.
        """
        return pulumi.get(self, "childrens")

    @property
    @pulumi.getter(name="conditionType")
    def condition_type(self) -> builtins.str:
        """
        Indicates whether the record is the condition itself or a logical aggregation. Logical aggreation indicates that additional conditions are present under the children attribute.
        """
        return pulumi.get(self, "condition_type")

    @property
    @pulumi.getter(name="dictionaryName")
    def dictionary_name(self) -> builtins.str:
        """
        Dictionary name
        """
        return pulumi.get(self, "dictionary_name")

    @property
    @pulumi.getter(name="dictionaryValue")
    def dictionary_value(self) -> builtins.str:
        """
        Dictionary value
        """
        return pulumi.get(self, "dictionary_value")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        UUID for condition
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isNegate")
    def is_negate(self) -> builtins.bool:
        """
        Indicates whereas this condition is in negate mode
        """
        return pulumi.get(self, "is_negate")

    @property
    @pulumi.getter
    def operator(self) -> builtins.str:
        """
        Equality operator
        """
        return pulumi.get(self, "operator")


@pulumi.output_type
class GetAuthorizationGlobalExceptionRuleChildrenChildrenResult(dict):
    def __init__(__self__, *,
                 attribute_name: builtins.str,
                 attribute_value: builtins.str,
                 condition_type: builtins.str,
                 dictionary_name: builtins.str,
                 dictionary_value: builtins.str,
                 id: builtins.str,
                 is_negate: builtins.bool,
                 operator: builtins.str):
        """
        :param builtins.str attribute_name: Dictionary attribute name
        :param builtins.str attribute_value: Attribute value for condition. Value type is specified in dictionary object.
        :param builtins.str condition_type: Condition type.
        :param builtins.str dictionary_name: Dictionary name
        :param builtins.str dictionary_value: Dictionary value
        :param builtins.str id: UUID for condition
        :param builtins.bool is_negate: Indicates whereas this condition is in negate mode
        :param builtins.str operator: Equality operator
        """
        pulumi.set(__self__, "attribute_name", attribute_name)
        pulumi.set(__self__, "attribute_value", attribute_value)
        pulumi.set(__self__, "condition_type", condition_type)
        pulumi.set(__self__, "dictionary_name", dictionary_name)
        pulumi.set(__self__, "dictionary_value", dictionary_value)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "is_negate", is_negate)
        pulumi.set(__self__, "operator", operator)

    @property
    @pulumi.getter(name="attributeName")
    def attribute_name(self) -> builtins.str:
        """
        Dictionary attribute name
        """
        return pulumi.get(self, "attribute_name")

    @property
    @pulumi.getter(name="attributeValue")
    def attribute_value(self) -> builtins.str:
        """
        Attribute value for condition. Value type is specified in dictionary object.
        """
        return pulumi.get(self, "attribute_value")

    @property
    @pulumi.getter(name="conditionType")
    def condition_type(self) -> builtins.str:
        """
        Condition type.
        """
        return pulumi.get(self, "condition_type")

    @property
    @pulumi.getter(name="dictionaryName")
    def dictionary_name(self) -> builtins.str:
        """
        Dictionary name
        """
        return pulumi.get(self, "dictionary_name")

    @property
    @pulumi.getter(name="dictionaryValue")
    def dictionary_value(self) -> builtins.str:
        """
        Dictionary value
        """
        return pulumi.get(self, "dictionary_value")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        UUID for condition
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isNegate")
    def is_negate(self) -> builtins.bool:
        """
        Indicates whereas this condition is in negate mode
        """
        return pulumi.get(self, "is_negate")

    @property
    @pulumi.getter
    def operator(self) -> builtins.str:
        """
        Equality operator
        """
        return pulumi.get(self, "operator")


@pulumi.output_type
class GetAuthorizationProfileAdvancedAttributeResult(dict):
    def __init__(__self__, *,
                 attribute_left_dictionary_name: builtins.str,
                 attribute_left_name: builtins.str,
                 attribute_right_dictionary_name: builtins.str,
                 attribute_right_name: builtins.str,
                 attribute_right_value: builtins.str,
                 attribute_right_value_type: builtins.str):
        """
        :param builtins.str attribute_left_dictionary_name: Dictionary name
        :param builtins.str attribute_left_name: Attribute name
        :param builtins.str attribute_right_dictionary_name: Dictionary name, only required when `attribute_right_value_type` is `AdvancedDictionaryAttribute`
        :param builtins.str attribute_right_name: Attribute name, only required when `attribute_right_value_type` is `AdvancedDictionaryAttribute`
        :param builtins.str attribute_right_value: Attribute value, only required when `attribute_right_value_type` is `AttributeValue`
        :param builtins.str attribute_right_value_type: Advanced attribute value type
        """
        pulumi.set(__self__, "attribute_left_dictionary_name", attribute_left_dictionary_name)
        pulumi.set(__self__, "attribute_left_name", attribute_left_name)
        pulumi.set(__self__, "attribute_right_dictionary_name", attribute_right_dictionary_name)
        pulumi.set(__self__, "attribute_right_name", attribute_right_name)
        pulumi.set(__self__, "attribute_right_value", attribute_right_value)
        pulumi.set(__self__, "attribute_right_value_type", attribute_right_value_type)

    @property
    @pulumi.getter(name="attributeLeftDictionaryName")
    def attribute_left_dictionary_name(self) -> builtins.str:
        """
        Dictionary name
        """
        return pulumi.get(self, "attribute_left_dictionary_name")

    @property
    @pulumi.getter(name="attributeLeftName")
    def attribute_left_name(self) -> builtins.str:
        """
        Attribute name
        """
        return pulumi.get(self, "attribute_left_name")

    @property
    @pulumi.getter(name="attributeRightDictionaryName")
    def attribute_right_dictionary_name(self) -> builtins.str:
        """
        Dictionary name, only required when `attribute_right_value_type` is `AdvancedDictionaryAttribute`
        """
        return pulumi.get(self, "attribute_right_dictionary_name")

    @property
    @pulumi.getter(name="attributeRightName")
    def attribute_right_name(self) -> builtins.str:
        """
        Attribute name, only required when `attribute_right_value_type` is `AdvancedDictionaryAttribute`
        """
        return pulumi.get(self, "attribute_right_name")

    @property
    @pulumi.getter(name="attributeRightValue")
    def attribute_right_value(self) -> builtins.str:
        """
        Attribute value, only required when `attribute_right_value_type` is `AttributeValue`
        """
        return pulumi.get(self, "attribute_right_value")

    @property
    @pulumi.getter(name="attributeRightValueType")
    def attribute_right_value_type(self) -> builtins.str:
        """
        Advanced attribute value type
        """
        return pulumi.get(self, "attribute_right_value_type")


@pulumi.output_type
class GetAuthorizationRuleChildrenResult(dict):
    def __init__(__self__, *,
                 attribute_name: builtins.str,
                 attribute_value: builtins.str,
                 childrens: Sequence['outputs.GetAuthorizationRuleChildrenChildrenResult'],
                 condition_type: builtins.str,
                 dictionary_name: builtins.str,
                 dictionary_value: builtins.str,
                 id: builtins.str,
                 is_negate: builtins.bool,
                 operator: builtins.str):
        """
        :param builtins.str attribute_name: Dictionary attribute name
        :param builtins.str attribute_value: Attribute value for condition. Value type is specified in dictionary object.
        :param Sequence['GetAuthorizationRuleChildrenChildrenArgs'] childrens: List of child conditions. `condition_type` must be one of `ConditionAndBlock` or `ConditionOrBlock`.
        :param builtins.str condition_type: Indicates whether the record is the condition itself or a logical aggregation. Logical aggreation indicates that additional conditions are present under the children attribute.
        :param builtins.str dictionary_name: Dictionary name
        :param builtins.str dictionary_value: Dictionary value
        :param builtins.str id: UUID for condition
        :param builtins.bool is_negate: Indicates whereas this condition is in negate mode
        :param builtins.str operator: Equality operator
        """
        pulumi.set(__self__, "attribute_name", attribute_name)
        pulumi.set(__self__, "attribute_value", attribute_value)
        pulumi.set(__self__, "childrens", childrens)
        pulumi.set(__self__, "condition_type", condition_type)
        pulumi.set(__self__, "dictionary_name", dictionary_name)
        pulumi.set(__self__, "dictionary_value", dictionary_value)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "is_negate", is_negate)
        pulumi.set(__self__, "operator", operator)

    @property
    @pulumi.getter(name="attributeName")
    def attribute_name(self) -> builtins.str:
        """
        Dictionary attribute name
        """
        return pulumi.get(self, "attribute_name")

    @property
    @pulumi.getter(name="attributeValue")
    def attribute_value(self) -> builtins.str:
        """
        Attribute value for condition. Value type is specified in dictionary object.
        """
        return pulumi.get(self, "attribute_value")

    @property
    @pulumi.getter
    def childrens(self) -> Sequence['outputs.GetAuthorizationRuleChildrenChildrenResult']:
        """
        List of child conditions. `condition_type` must be one of `ConditionAndBlock` or `ConditionOrBlock`.
        """
        return pulumi.get(self, "childrens")

    @property
    @pulumi.getter(name="conditionType")
    def condition_type(self) -> builtins.str:
        """
        Indicates whether the record is the condition itself or a logical aggregation. Logical aggreation indicates that additional conditions are present under the children attribute.
        """
        return pulumi.get(self, "condition_type")

    @property
    @pulumi.getter(name="dictionaryName")
    def dictionary_name(self) -> builtins.str:
        """
        Dictionary name
        """
        return pulumi.get(self, "dictionary_name")

    @property
    @pulumi.getter(name="dictionaryValue")
    def dictionary_value(self) -> builtins.str:
        """
        Dictionary value
        """
        return pulumi.get(self, "dictionary_value")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        UUID for condition
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isNegate")
    def is_negate(self) -> builtins.bool:
        """
        Indicates whereas this condition is in negate mode
        """
        return pulumi.get(self, "is_negate")

    @property
    @pulumi.getter
    def operator(self) -> builtins.str:
        """
        Equality operator
        """
        return pulumi.get(self, "operator")


@pulumi.output_type
class GetAuthorizationRuleChildrenChildrenResult(dict):
    def __init__(__self__, *,
                 attribute_name: builtins.str,
                 attribute_value: builtins.str,
                 condition_type: builtins.str,
                 dictionary_name: builtins.str,
                 dictionary_value: builtins.str,
                 id: builtins.str,
                 is_negate: builtins.bool,
                 operator: builtins.str):
        """
        :param builtins.str attribute_name: Dictionary attribute name
        :param builtins.str attribute_value: Attribute value for condition. Value type is specified in dictionary object.
        :param builtins.str condition_type: Condition type.
        :param builtins.str dictionary_name: Dictionary name
        :param builtins.str dictionary_value: Dictionary value
        :param builtins.str id: UUID for condition
        :param builtins.bool is_negate: Indicates whereas this condition is in negate mode
        :param builtins.str operator: Equality operator
        """
        pulumi.set(__self__, "attribute_name", attribute_name)
        pulumi.set(__self__, "attribute_value", attribute_value)
        pulumi.set(__self__, "condition_type", condition_type)
        pulumi.set(__self__, "dictionary_name", dictionary_name)
        pulumi.set(__self__, "dictionary_value", dictionary_value)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "is_negate", is_negate)
        pulumi.set(__self__, "operator", operator)

    @property
    @pulumi.getter(name="attributeName")
    def attribute_name(self) -> builtins.str:
        """
        Dictionary attribute name
        """
        return pulumi.get(self, "attribute_name")

    @property
    @pulumi.getter(name="attributeValue")
    def attribute_value(self) -> builtins.str:
        """
        Attribute value for condition. Value type is specified in dictionary object.
        """
        return pulumi.get(self, "attribute_value")

    @property
    @pulumi.getter(name="conditionType")
    def condition_type(self) -> builtins.str:
        """
        Condition type.
        """
        return pulumi.get(self, "condition_type")

    @property
    @pulumi.getter(name="dictionaryName")
    def dictionary_name(self) -> builtins.str:
        """
        Dictionary name
        """
        return pulumi.get(self, "dictionary_name")

    @property
    @pulumi.getter(name="dictionaryValue")
    def dictionary_value(self) -> builtins.str:
        """
        Dictionary value
        """
        return pulumi.get(self, "dictionary_value")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        UUID for condition
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isNegate")
    def is_negate(self) -> builtins.bool:
        """
        Indicates whereas this condition is in negate mode
        """
        return pulumi.get(self, "is_negate")

    @property
    @pulumi.getter
    def operator(self) -> builtins.str:
        """
        Equality operator
        """
        return pulumi.get(self, "operator")


@pulumi.output_type
class GetConditionChildrenResult(dict):
    def __init__(__self__, *,
                 attribute_name: builtins.str,
                 attribute_value: builtins.str,
                 childrens: Sequence['outputs.GetConditionChildrenChildrenResult'],
                 condition_type: builtins.str,
                 description: builtins.str,
                 dictionary_name: builtins.str,
                 dictionary_value: builtins.str,
                 id: builtins.str,
                 is_negate: builtins.bool,
                 name: builtins.str,
                 operator: builtins.str):
        """
        :param builtins.str attribute_name: Dictionary attribute name
        :param builtins.str attribute_value: Attribute value for condition. Value type is specified in dictionary object.
        :param Sequence['GetConditionChildrenChildrenArgs'] childrens: List of child conditions. `condition_type` must be one of `ConditionAndBlock` or `ConditionOrBlock`.
        :param builtins.str condition_type: Indicates whether the record is the condition itself or a logical aggregation. Logical aggreation indicates that additional conditions are present under the children attribute.
        :param builtins.str description: Condition description
        :param builtins.str dictionary_name: Dictionary name
        :param builtins.str dictionary_value: Dictionary value
        :param builtins.str id: UUID for condition
        :param builtins.bool is_negate: Indicates whereas this condition is in negate mode
        :param builtins.str name: Condition name
        :param builtins.str operator: Equality operator
        """
        pulumi.set(__self__, "attribute_name", attribute_name)
        pulumi.set(__self__, "attribute_value", attribute_value)
        pulumi.set(__self__, "childrens", childrens)
        pulumi.set(__self__, "condition_type", condition_type)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "dictionary_name", dictionary_name)
        pulumi.set(__self__, "dictionary_value", dictionary_value)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "is_negate", is_negate)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "operator", operator)

    @property
    @pulumi.getter(name="attributeName")
    def attribute_name(self) -> builtins.str:
        """
        Dictionary attribute name
        """
        return pulumi.get(self, "attribute_name")

    @property
    @pulumi.getter(name="attributeValue")
    def attribute_value(self) -> builtins.str:
        """
        Attribute value for condition. Value type is specified in dictionary object.
        """
        return pulumi.get(self, "attribute_value")

    @property
    @pulumi.getter
    def childrens(self) -> Sequence['outputs.GetConditionChildrenChildrenResult']:
        """
        List of child conditions. `condition_type` must be one of `ConditionAndBlock` or `ConditionOrBlock`.
        """
        return pulumi.get(self, "childrens")

    @property
    @pulumi.getter(name="conditionType")
    def condition_type(self) -> builtins.str:
        """
        Indicates whether the record is the condition itself or a logical aggregation. Logical aggreation indicates that additional conditions are present under the children attribute.
        """
        return pulumi.get(self, "condition_type")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        Condition description
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="dictionaryName")
    def dictionary_name(self) -> builtins.str:
        """
        Dictionary name
        """
        return pulumi.get(self, "dictionary_name")

    @property
    @pulumi.getter(name="dictionaryValue")
    def dictionary_value(self) -> builtins.str:
        """
        Dictionary value
        """
        return pulumi.get(self, "dictionary_value")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        UUID for condition
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isNegate")
    def is_negate(self) -> builtins.bool:
        """
        Indicates whereas this condition is in negate mode
        """
        return pulumi.get(self, "is_negate")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        Condition name
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def operator(self) -> builtins.str:
        """
        Equality operator
        """
        return pulumi.get(self, "operator")


@pulumi.output_type
class GetConditionChildrenChildrenResult(dict):
    def __init__(__self__, *,
                 attribute_name: builtins.str,
                 attribute_value: builtins.str,
                 condition_type: builtins.str,
                 description: builtins.str,
                 dictionary_name: builtins.str,
                 dictionary_value: builtins.str,
                 id: builtins.str,
                 is_negate: builtins.bool,
                 name: builtins.str,
                 operator: builtins.str):
        """
        :param builtins.str attribute_name: Dictionary attribute name
        :param builtins.str attribute_value: Attribute value for condition. Value type is specified in dictionary object.
        :param builtins.str condition_type: Condition type.
        :param builtins.str description: Condition description
        :param builtins.str dictionary_name: Dictionary name
        :param builtins.str dictionary_value: Dictionary value
        :param builtins.str id: UUID for condition
        :param builtins.bool is_negate: Indicates whereas this condition is in negate mode
        :param builtins.str name: Condition name
        :param builtins.str operator: Equality operator
        """
        pulumi.set(__self__, "attribute_name", attribute_name)
        pulumi.set(__self__, "attribute_value", attribute_value)
        pulumi.set(__self__, "condition_type", condition_type)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "dictionary_name", dictionary_name)
        pulumi.set(__self__, "dictionary_value", dictionary_value)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "is_negate", is_negate)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "operator", operator)

    @property
    @pulumi.getter(name="attributeName")
    def attribute_name(self) -> builtins.str:
        """
        Dictionary attribute name
        """
        return pulumi.get(self, "attribute_name")

    @property
    @pulumi.getter(name="attributeValue")
    def attribute_value(self) -> builtins.str:
        """
        Attribute value for condition. Value type is specified in dictionary object.
        """
        return pulumi.get(self, "attribute_value")

    @property
    @pulumi.getter(name="conditionType")
    def condition_type(self) -> builtins.str:
        """
        Condition type.
        """
        return pulumi.get(self, "condition_type")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        Condition description
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="dictionaryName")
    def dictionary_name(self) -> builtins.str:
        """
        Dictionary name
        """
        return pulumi.get(self, "dictionary_name")

    @property
    @pulumi.getter(name="dictionaryValue")
    def dictionary_value(self) -> builtins.str:
        """
        Dictionary value
        """
        return pulumi.get(self, "dictionary_value")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        UUID for condition
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isNegate")
    def is_negate(self) -> builtins.bool:
        """
        Indicates whereas this condition is in negate mode
        """
        return pulumi.get(self, "is_negate")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        Condition name
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def operator(self) -> builtins.str:
        """
        Equality operator
        """
        return pulumi.get(self, "operator")


@pulumi.output_type
class GetPolicySetChildrenResult(dict):
    def __init__(__self__, *,
                 attribute_name: builtins.str,
                 attribute_value: builtins.str,
                 childrens: Sequence['outputs.GetPolicySetChildrenChildrenResult'],
                 condition_type: builtins.str,
                 dictionary_name: builtins.str,
                 dictionary_value: builtins.str,
                 id: builtins.str,
                 is_negate: builtins.bool,
                 operator: builtins.str):
        """
        :param builtins.str attribute_name: Dictionary attribute name
        :param builtins.str attribute_value: Attribute value for condition. Value type is specified in dictionary object.
        :param Sequence['GetPolicySetChildrenChildrenArgs'] childrens: List of child conditions. `condition_type` must be one of `ConditionAndBlock` or `ConditionOrBlock`.
        :param builtins.str condition_type: Indicates whether the record is the condition itself or a logical aggregation. Logical aggreation indicates that additional conditions are present under the children attribute.
        :param builtins.str dictionary_name: Dictionary name
        :param builtins.str dictionary_value: Dictionary value
        :param builtins.str id: UUID for condition
        :param builtins.bool is_negate: Indicates whereas this condition is in negate mode
        :param builtins.str operator: Equality operator
        """
        pulumi.set(__self__, "attribute_name", attribute_name)
        pulumi.set(__self__, "attribute_value", attribute_value)
        pulumi.set(__self__, "childrens", childrens)
        pulumi.set(__self__, "condition_type", condition_type)
        pulumi.set(__self__, "dictionary_name", dictionary_name)
        pulumi.set(__self__, "dictionary_value", dictionary_value)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "is_negate", is_negate)
        pulumi.set(__self__, "operator", operator)

    @property
    @pulumi.getter(name="attributeName")
    def attribute_name(self) -> builtins.str:
        """
        Dictionary attribute name
        """
        return pulumi.get(self, "attribute_name")

    @property
    @pulumi.getter(name="attributeValue")
    def attribute_value(self) -> builtins.str:
        """
        Attribute value for condition. Value type is specified in dictionary object.
        """
        return pulumi.get(self, "attribute_value")

    @property
    @pulumi.getter
    def childrens(self) -> Sequence['outputs.GetPolicySetChildrenChildrenResult']:
        """
        List of child conditions. `condition_type` must be one of `ConditionAndBlock` or `ConditionOrBlock`.
        """
        return pulumi.get(self, "childrens")

    @property
    @pulumi.getter(name="conditionType")
    def condition_type(self) -> builtins.str:
        """
        Indicates whether the record is the condition itself or a logical aggregation. Logical aggreation indicates that additional conditions are present under the children attribute.
        """
        return pulumi.get(self, "condition_type")

    @property
    @pulumi.getter(name="dictionaryName")
    def dictionary_name(self) -> builtins.str:
        """
        Dictionary name
        """
        return pulumi.get(self, "dictionary_name")

    @property
    @pulumi.getter(name="dictionaryValue")
    def dictionary_value(self) -> builtins.str:
        """
        Dictionary value
        """
        return pulumi.get(self, "dictionary_value")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        UUID for condition
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isNegate")
    def is_negate(self) -> builtins.bool:
        """
        Indicates whereas this condition is in negate mode
        """
        return pulumi.get(self, "is_negate")

    @property
    @pulumi.getter
    def operator(self) -> builtins.str:
        """
        Equality operator
        """
        return pulumi.get(self, "operator")


@pulumi.output_type
class GetPolicySetChildrenChildrenResult(dict):
    def __init__(__self__, *,
                 attribute_name: builtins.str,
                 attribute_value: builtins.str,
                 condition_type: builtins.str,
                 dictionary_name: builtins.str,
                 dictionary_value: builtins.str,
                 id: builtins.str,
                 is_negate: builtins.bool,
                 operator: builtins.str):
        """
        :param builtins.str attribute_name: Dictionary attribute name
        :param builtins.str attribute_value: Attribute value for condition. Value type is specified in dictionary object.
        :param builtins.str condition_type: Condition type.
        :param builtins.str dictionary_name: Dictionary name
        :param builtins.str dictionary_value: Dictionary value
        :param builtins.str id: UUID for condition
        :param builtins.bool is_negate: Indicates whereas this condition is in negate mode
        :param builtins.str operator: Equality operator
        """
        pulumi.set(__self__, "attribute_name", attribute_name)
        pulumi.set(__self__, "attribute_value", attribute_value)
        pulumi.set(__self__, "condition_type", condition_type)
        pulumi.set(__self__, "dictionary_name", dictionary_name)
        pulumi.set(__self__, "dictionary_value", dictionary_value)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "is_negate", is_negate)
        pulumi.set(__self__, "operator", operator)

    @property
    @pulumi.getter(name="attributeName")
    def attribute_name(self) -> builtins.str:
        """
        Dictionary attribute name
        """
        return pulumi.get(self, "attribute_name")

    @property
    @pulumi.getter(name="attributeValue")
    def attribute_value(self) -> builtins.str:
        """
        Attribute value for condition. Value type is specified in dictionary object.
        """
        return pulumi.get(self, "attribute_value")

    @property
    @pulumi.getter(name="conditionType")
    def condition_type(self) -> builtins.str:
        """
        Condition type.
        """
        return pulumi.get(self, "condition_type")

    @property
    @pulumi.getter(name="dictionaryName")
    def dictionary_name(self) -> builtins.str:
        """
        Dictionary name
        """
        return pulumi.get(self, "dictionary_name")

    @property
    @pulumi.getter(name="dictionaryValue")
    def dictionary_value(self) -> builtins.str:
        """
        Dictionary value
        """
        return pulumi.get(self, "dictionary_value")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        UUID for condition
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isNegate")
    def is_negate(self) -> builtins.bool:
        """
        Indicates whereas this condition is in negate mode
        """
        return pulumi.get(self, "is_negate")

    @property
    @pulumi.getter
    def operator(self) -> builtins.str:
        """
        Equality operator
        """
        return pulumi.get(self, "operator")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['SxpDomainFilterArgs', 'SxpDomainFilter']

@pulumi.input_type
class SxpDomainFilterArgs:
    def __init__(__self__, *,
                 domains: pulumi.Input[builtins.str],
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 sgt: Optional[pulumi.Input[builtins.str]] = None,
                 subnet: Optional[pulumi.Input[builtins.str]] = None,
                 vn: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a SxpDomainFilter resource.
        :param pulumi.Input[builtins.str] domains: List of SXP Domains, separated with comma
        :param pulumi.Input[builtins.str] description: Description
        :param pulumi.Input[builtins.str] name: Resource name
        :param pulumi.Input[builtins.str] sgt: SGT name or ID. At least one of subnet or sgt or vn should be defined
        :param pulumi.Input[builtins.str] subnet: Subnet for filter policy (hostname is not supported). At least one of subnet or sgt or vn should be defined
        :param pulumi.Input[builtins.str] vn: Virtual Network. At least one of subnet or sgt or vn should be defined
        """
        pulumi.set(__self__, "domains", domains)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if sgt is not None:
            pulumi.set(__self__, "sgt", sgt)
        if subnet is not None:
            pulumi.set(__self__, "subnet", subnet)
        if vn is not None:
            pulumi.set(__self__, "vn", vn)

    @property
    @pulumi.getter
    def domains(self) -> pulumi.Input[builtins.str]:
        """
        List of SXP Domains, separated with comma
        """
        return pulumi.get(self, "domains")

    @domains.setter
    def domains(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "domains", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Resource name
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def sgt(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        SGT name or ID. At least one of subnet or sgt or vn should be defined
        """
        return pulumi.get(self, "sgt")

    @sgt.setter
    def sgt(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "sgt", value)

    @property
    @pulumi.getter
    def subnet(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Subnet for filter policy (hostname is not supported). At least one of subnet or sgt or vn should be defined
        """
        return pulumi.get(self, "subnet")

    @subnet.setter
    def subnet(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "subnet", value)

    @property
    @pulumi.getter
    def vn(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Virtual Network. At least one of subnet or sgt or vn should be defined
        """
        return pulumi.get(self, "vn")

    @vn.setter
    def vn(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vn", value)


@pulumi.input_type
class _SxpDomainFilterState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 domains: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 sgt: Optional[pulumi.Input[builtins.str]] = None,
                 subnet: Optional[pulumi.Input[builtins.str]] = None,
                 vn: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering SxpDomainFilter resources.
        :param pulumi.Input[builtins.str] description: Description
        :param pulumi.Input[builtins.str] domains: List of SXP Domains, separated with comma
        :param pulumi.Input[builtins.str] name: Resource name
        :param pulumi.Input[builtins.str] sgt: SGT name or ID. At least one of subnet or sgt or vn should be defined
        :param pulumi.Input[builtins.str] subnet: Subnet for filter policy (hostname is not supported). At least one of subnet or sgt or vn should be defined
        :param pulumi.Input[builtins.str] vn: Virtual Network. At least one of subnet or sgt or vn should be defined
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if domains is not None:
            pulumi.set(__self__, "domains", domains)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if sgt is not None:
            pulumi.set(__self__, "sgt", sgt)
        if subnet is not None:
            pulumi.set(__self__, "subnet", subnet)
        if vn is not None:
            pulumi.set(__self__, "vn", vn)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def domains(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        List of SXP Domains, separated with comma
        """
        return pulumi.get(self, "domains")

    @domains.setter
    def domains(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "domains", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Resource name
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def sgt(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        SGT name or ID. At least one of subnet or sgt or vn should be defined
        """
        return pulumi.get(self, "sgt")

    @sgt.setter
    def sgt(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "sgt", value)

    @property
    @pulumi.getter
    def subnet(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Subnet for filter policy (hostname is not supported). At least one of subnet or sgt or vn should be defined
        """
        return pulumi.get(self, "subnet")

    @subnet.setter
    def subnet(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "subnet", value)

    @property
    @pulumi.getter
    def vn(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Virtual Network. At least one of subnet or sgt or vn should be defined
        """
        return pulumi.get(self, "vn")

    @vn.setter
    def vn(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vn", value)


class SxpDomainFilter(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 domains: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 sgt: Optional[pulumi.Input[builtins.str]] = None,
                 subnet: Optional[pulumi.Input[builtins.str]] = None,
                 vn: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        This resource can manage a SXP Domain Filter.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ise as ise

        example = ise.trustsec.SxpDomainFilter("example",
            subnet="1.0.0.0/24",
            vn="VN1",
            domains="default")
        ```

        ## Import

        ```sh
        $ pulumi import ise:trustsec/sxpDomainFilter:SxpDomainFilter example "76d24097-41c4-4558-a4d0-a8c07ac08470"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: Description
        :param pulumi.Input[builtins.str] domains: List of SXP Domains, separated with comma
        :param pulumi.Input[builtins.str] name: Resource name
        :param pulumi.Input[builtins.str] sgt: SGT name or ID. At least one of subnet or sgt or vn should be defined
        :param pulumi.Input[builtins.str] subnet: Subnet for filter policy (hostname is not supported). At least one of subnet or sgt or vn should be defined
        :param pulumi.Input[builtins.str] vn: Virtual Network. At least one of subnet or sgt or vn should be defined
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SxpDomainFilterArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource can manage a SXP Domain Filter.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ise as ise

        example = ise.trustsec.SxpDomainFilter("example",
            subnet="1.0.0.0/24",
            vn="VN1",
            domains="default")
        ```

        ## Import

        ```sh
        $ pulumi import ise:trustsec/sxpDomainFilter:SxpDomainFilter example "76d24097-41c4-4558-a4d0-a8c07ac08470"
        ```

        :param str resource_name: The name of the resource.
        :param SxpDomainFilterArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SxpDomainFilterArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 domains: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 sgt: Optional[pulumi.Input[builtins.str]] = None,
                 subnet: Optional[pulumi.Input[builtins.str]] = None,
                 vn: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SxpDomainFilterArgs.__new__(SxpDomainFilterArgs)

            __props__.__dict__["description"] = description
            if domains is None and not opts.urn:
                raise TypeError("Missing required property 'domains'")
            __props__.__dict__["domains"] = domains
            __props__.__dict__["name"] = name
            __props__.__dict__["sgt"] = sgt
            __props__.__dict__["subnet"] = subnet
            __props__.__dict__["vn"] = vn
        super(SxpDomainFilter, __self__).__init__(
            'ise:trustsec/sxpDomainFilter:SxpDomainFilter',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            domains: Optional[pulumi.Input[builtins.str]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            sgt: Optional[pulumi.Input[builtins.str]] = None,
            subnet: Optional[pulumi.Input[builtins.str]] = None,
            vn: Optional[pulumi.Input[builtins.str]] = None) -> 'SxpDomainFilter':
        """
        Get an existing SxpDomainFilter resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: Description
        :param pulumi.Input[builtins.str] domains: List of SXP Domains, separated with comma
        :param pulumi.Input[builtins.str] name: Resource name
        :param pulumi.Input[builtins.str] sgt: SGT name or ID. At least one of subnet or sgt or vn should be defined
        :param pulumi.Input[builtins.str] subnet: Subnet for filter policy (hostname is not supported). At least one of subnet or sgt or vn should be defined
        :param pulumi.Input[builtins.str] vn: Virtual Network. At least one of subnet or sgt or vn should be defined
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SxpDomainFilterState.__new__(_SxpDomainFilterState)

        __props__.__dict__["description"] = description
        __props__.__dict__["domains"] = domains
        __props__.__dict__["name"] = name
        __props__.__dict__["sgt"] = sgt
        __props__.__dict__["subnet"] = subnet
        __props__.__dict__["vn"] = vn
        return SxpDomainFilter(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Description
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def domains(self) -> pulumi.Output[builtins.str]:
        """
        List of SXP Domains, separated with comma
        """
        return pulumi.get(self, "domains")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        Resource name
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def sgt(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        SGT name or ID. At least one of subnet or sgt or vn should be defined
        """
        return pulumi.get(self, "sgt")

    @property
    @pulumi.getter
    def subnet(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Subnet for filter policy (hostname is not supported). At least one of subnet or sgt or vn should be defined
        """
        return pulumi.get(self, "subnet")

    @property
    @pulumi.getter
    def vn(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Virtual Network. At least one of subnet or sgt or vn should be defined
        """
        return pulumi.get(self, "vn")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

insecure: Optional[bool]
"""
Allow insecure HTTPS client. This can also be set as the ISE_INSECURE environment variable. Defaults to `true`.
"""

password: Optional[str]
"""
Password for the ISE instance. This can also be set as the ISE_PASSWORD environment variable.
"""

retries: Optional[int]
"""
Number of retries for REST API calls. This can also be set as the ISE_RETRIES environment variable. Defaults to `3`.
"""

url: Optional[str]
"""
URL of the Cisco ISE instance. This can also be set as the ISE_URL environment variable.
"""

username: Optional[str]
"""
Username for the ISE instance. This can also be set as the ISE_USERNAME environment variable.
"""

